@@ -92,8 +92,16 @@ lbh_get_body_content(LibBalsaMessageBody * body, gchar ** buf)
 #define d(x)
 #endif
 
+/* WebKitContextMenuItem uses GtkAction, which is deprecated.
+ * We don't use it, but it breaks the git-tree build, so we just mangle
+ * it: */
+#if defined(GTK_DISABLE_DEPRECATED)
+#define GtkAction GAction
 #include <webkit2/webkit2.h>
-#include <JavaScriptCore/JavaScript.h>
+#undef GtkAction
+#else  /* defined(GTK_DISABLE_DEPRECATED) */
+#include <webkit2/webkit2.h>
+#endif /* defined(GTK_DISABLE_DEPRECATED) */
 
 typedef struct {
     LibBalsaMessageBody  *body;
@@ -199,31 +207,33 @@ static void
 lbh_navigation_policy_decision(WebKitPolicyDecision * decision,
                                gpointer               data)
 {
-    WebKitNavigationPolicyDecision *navigation_decision =
-        WEBKIT_NAVIGATION_POLICY_DECISION(decision);
+    WebKitNavigationPolicyDecision *navigation_decision;
+    WebKitNavigationAction *navigation_action;
     LibBalsaWebKitInfo *info = data;
     WebKitURIRequest *request;
 
-    switch (webkit_navigation_policy_decision_get_navigation_type
-            (navigation_decision)) {
+    navigation_decision = WEBKIT_NAVIGATION_POLICY_DECISION(decision);
+    navigation_action =
+         webkit_navigation_policy_decision_get_navigation_action
+            (navigation_decision);
+    switch (webkit_navigation_action_get_navigation_type
+            (navigation_action)) {
     case WEBKIT_NAVIGATION_TYPE_OTHER:
     case WEBKIT_NAVIGATION_TYPE_RELOAD:
         d(g_print("%s type %d, used\n", __func__,
-                  webkit_navigation_policy_decision_get_navigation_type
-                  (navigation_decision)));
+                  webkit_navigation_action_get_navigation_type
+                  (navigation_action)));
         webkit_policy_decision_use(decision);
         break;
     case WEBKIT_NAVIGATION_TYPE_LINK_CLICKED:
-        request =
-            webkit_navigation_policy_decision_get_request
-            (navigation_decision);
+        request = webkit_navigation_action_get_request(navigation_action);
         d(g_print("%s clicked %s\n", __func__,
                   webkit_uri_request_get_uri(request)));
         (*info->clicked_cb) (webkit_uri_request_get_uri(request));
     default:
         d(g_print("%s type %d, ignored\n", __func__,
-                  webkit_navigation_policy_decision_get_navigation_type
-                  (navigation_decision)));
+                  webkit_navigation_action_get_navigation_type
+                  (navigation_action)));
         webkit_policy_decision_ignore(decision);
     }
 }
@@ -232,24 +242,26 @@ static void
 lbh_new_window_policy_decision(WebKitPolicyDecision * decision,
                                gpointer               data)
 {
-    WebKitNavigationPolicyDecision *navigation_decision =
-        WEBKIT_NAVIGATION_POLICY_DECISION(decision);
+    WebKitNavigationPolicyDecision *navigation_decision;
+    WebKitNavigationAction *navigation_action;
     LibBalsaWebKitInfo *info = data;
     WebKitURIRequest *request;
 
-    switch (webkit_navigation_policy_decision_get_navigation_type
-            (navigation_decision)) {
-    case WEBKIT_NAVIGATION_TYPE_LINK_CLICKED:
-        request =
-            webkit_navigation_policy_decision_get_request
+    navigation_decision = WEBKIT_NAVIGATION_POLICY_DECISION(decision);
+    navigation_action =
+         webkit_navigation_policy_decision_get_navigation_action
             (navigation_decision);
+    switch (webkit_navigation_action_get_navigation_type
+            (navigation_action)) {
+    case WEBKIT_NAVIGATION_TYPE_LINK_CLICKED:
+        request = webkit_navigation_action_get_request(navigation_action);
         d(g_print("%s clicked %s\n", __func__,
                   webkit_uri_request_get_uri(request)));
         (*info->clicked_cb) (webkit_uri_request_get_uri(request));
     default:
         d(g_print("%s type %d, ignored\n", __func__,
-                  webkit_navigation_policy_decision_get_navigation_type
-                  (navigation_decision)));
+                  webkit_navigation_action_get_navigation_type
+                  (navigation_action)));
 
         webkit_policy_decision_ignore(decision);
     }
@@ -333,6 +345,15 @@ lbh_info_bar(LibBalsaWebKitInfo * info)
     GtkInfoBar *info_bar;
     GtkWidget *label;
     GtkWidget *content_area;
+#ifdef GTK_INFO_BAR_WRAPPING_IS_BROKEN
+    static const gchar text[] =
+                 N_("This message part contains images "
+                    "from a remote server.\n"
+                    "To protect your privacy, "
+                    "Balsa has not downloaded them.\n"
+                    "You may choose to download them "
+                    "if you trust the server.");
+#else                           /* GTK_INFO_BAR_WRAPPING_IS_BROKEN */
     static const gchar text[] =
                  N_("This message part contains images "
                     "from a remote server. "
@@ -340,14 +361,18 @@ lbh_info_bar(LibBalsaWebKitInfo * info)
                     "Balsa has not downloaded them. "
                     "You may choose to download them "
                     "if you trust the server.");
+#endif                          /* GTK_INFO_BAR_WRAPPING_IS_BROKEN */
 
     info_bar_widget =
         gtk_info_bar_new_with_buttons(_("_Download images"),
                                      GTK_RESPONSE_OK,
-                                     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                                     _("_Close"), GTK_RESPONSE_CLOSE,
                                      NULL);
 
     info_bar = GTK_INFO_BAR(info_bar_widget);
+    gtk_orientable_set_orientation(GTK_ORIENTABLE
+                                   (gtk_info_bar_get_action_area
+                                    (info_bar)), GTK_ORIENTATION_VERTICAL);
 
     label = gtk_label_new(_(text));
     gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
@@ -987,7 +1012,7 @@ lbh_show_info_bar(LibBalsaWebKitInfo * info)
     info_bar_widget =
         gtk_info_bar_new_with_buttons(_("_Download images"),
                                      GTK_RESPONSE_OK,
-                                     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                                     _("_Close"), GTK_RESPONSE_CLOSE,
                                      NULL);
     gtk_box_pack_start(GTK_BOX(info->vbox), info_bar_widget,
                        FALSE, FALSE, 0);
