@@ -117,6 +117,7 @@ libbalsa_identity_init(LibBalsaIdentity* ident)
     ident->crypt_protocol = LIBBALSA_PROTECT_OPENPGP;
     ident->force_key_id = NULL;
     ident->request_mdn = FALSE;
+    ident->request_dsn = FALSE;
     /*
     ident->face = NULL;
     ident->x_face = NULL;
@@ -407,7 +408,7 @@ libbalsa_identity_set_smtp_server(LibBalsaIdentity * ident,
 /* Used by both dialogs: */
 
 /* Widget padding: */
-static const guint padding = 12;
+static const guint padding = 6;
 
 /* Forward references: */
 static void identity_list_update_real(GtkTreeView * tree,
@@ -482,9 +483,10 @@ libbalsa_identity_select_dialog(GtkWindow * parent,
     sdi->idle_handler_id = 0;
     sdi->dialog = dialog =
         gtk_dialog_new_with_buttons(prompt, parent,
-                                    GTK_DIALOG_DESTROY_WITH_PARENT,
-                                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                    GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                    GTK_DIALOG_DESTROY_WITH_PARENT |
+                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                    _("_OK"),     GTK_RESPONSE_OK,
                                     NULL);
 #if HAVE_MACOSX_DESKTOP
     libbalsa_macosx_menu_for_parent(dialog, parent);
@@ -858,7 +860,7 @@ get_selected_identity(GtkTreeView * tree)
 
 enum {
     IDENTITY_RESPONSE_HELP = GTK_RESPONSE_HELP,
-    IDENTITY_RESPONSE_CLOSE,
+    IDENTITY_RESPONSE_CLOSE = GTK_RESPONSE_CANCEL,
     IDENTITY_RESPONSE_NEW,
     IDENTITY_RESPONSE_REMOVE
 };
@@ -913,11 +915,10 @@ new_ident_cb(GtkTreeView * tree, GObject * dialog)
 
 
 /*
- * Helper: append a notebook page containing a table with the requested
- * number of rows
+ * Helper: append a notebook page containing a table
  */
 static GtkWidget*
-append_ident_notebook_page(GtkNotebook *notebook, guint rows,
+append_ident_notebook_page(GtkNotebook *notebook,
 			   const gchar * tab_label,
                            const gchar * footnote)
 {
@@ -945,13 +946,13 @@ append_ident_notebook_page(GtkNotebook *notebook, guint rows,
  * Put the required GtkEntries, Labels, and Checkbuttons in the dialog
  * for creating/editing identities.
  */
-struct {
+static const struct {
     const gchar *mnemonic;
     const gchar *path_key;
     const gchar *box_key;
     const gchar *basename;
     const gchar *info;
-} static const path_info[] = {
+} path_info[] = {
         /* Translators: please do not translate Face. */
     {N_("_Face Path"),
      "identity-facepath",
@@ -987,7 +988,7 @@ setup_ident_frame(GtkDialog * dialog, gboolean createp, gpointer tree)
     gchar *footnote;
 
     /* create the "General" tab */
-    grid = append_ident_notebook_page(notebook, 5, _("General"), NULL);
+    grid = append_ident_notebook_page(notebook, _("General"), NULL);
     row = 0;
     ident_dialog_add_entry(grid, row++, dialog, _("_Identity name:"),
 		           "identity-name");
@@ -1001,7 +1002,7 @@ setup_ident_frame(GtkDialog * dialog, gboolean createp, gpointer tree)
                            "identity-domain");
 
     /* create the "Messages" tab */
-    grid = append_ident_notebook_page(notebook, 9, _("Messages"), NULL);
+    grid = append_ident_notebook_page(notebook, _("Messages"), NULL);
     row = 0;
     ident_dialog_add_entry(grid, row++, dialog, _("_Bcc:"),
                            "identity-bcc");
@@ -1012,6 +1013,10 @@ setup_ident_frame(GtkDialog * dialog, gboolean createp, gpointer tree)
     ident_dialog_add_checkbutton(grid, row++, dialog,
                                  _("send messages in both plain text and _HTML format"),
                                  "identity-sendmpalternative", TRUE);
+    ident_dialog_add_checkbutton(grid, row++, dialog,
+                                 _("request positive (successful)"
+                                   " _Delivery Status Notification by default"),
+                                 "identity-requestdsn", TRUE);
     ident_dialog_add_checkbutton(grid, row++, dialog,
                                  _("request _Message Disposition Notification by default"),
                                  "identity-requestmdn", TRUE);
@@ -1028,7 +1033,7 @@ setup_ident_frame(GtkDialog * dialog, gboolean createp, gpointer tree)
 #endif /* ENABLE_ESMTP */
 
     /* create the "Signature" tab */
-    grid = append_ident_notebook_page(notebook, 7, _("Signature"), NULL);
+    grid = append_ident_notebook_page(notebook, _("Signature"), NULL);
     row = 0;
     ident_dialog_add_check_and_entry(grid, row++, dialog,
                                      _("Signature _path"),
@@ -1060,7 +1065,7 @@ setup_ident_frame(GtkDialog * dialog, gboolean createp, gpointer tree)
 #endif
     /* create the "Security" tab */
     grid =
-        append_ident_notebook_page(notebook, 5, _("Security"), footnote);
+        append_ident_notebook_page(notebook, _("Security"), footnote);
     row = 0;
     ident_dialog_add_checkbutton(grid, row++, dialog,
                                  _("sign messages by default"),
@@ -1078,7 +1083,7 @@ setup_ident_frame(GtkDialog * dialog, gboolean createp, gpointer tree)
                                  _("remind me if messages can be encrypted"),
                                  "identity-warn-send-plain", TRUE);
     ident_dialog_add_entry(grid, row++, dialog,
-                           _("use secret key with this id for signing "
+                           _("use secret key with this id for signing\n"
                              "(leave empty for automatic selection)"),
                            "identity-keyid");
 #ifndef HAVE_GPGME
@@ -1492,6 +1497,7 @@ ident_dialog_update(GObject * dlg)
     g_free(id->x_face);
     id->x_face          = ident_dialog_get_path(dlg, "identity-xfacepath");
     id->request_mdn     = ident_dialog_get_bool(dlg, "identity-requestmdn");
+    id->request_dsn     = ident_dialog_get_bool(dlg, "identity-requestdsn");
 
     id->gpg_sign        = ident_dialog_get_bool(dlg, "identity-gpgsign");
     id->gpg_encrypt     = ident_dialog_get_bool(dlg, "identity-gpgencrypt");
@@ -1670,7 +1676,7 @@ help_ident_cb(GtkWidget * widget)
     GError *err = NULL;
 
     screen = gtk_widget_get_screen(widget);
-    gtk_show_uri(screen, "ghelp:balsa?identities",
+    gtk_show_uri(screen, "help:balsa/identities",
                  gtk_get_current_event_time(), &err);
 
     if (err) {
@@ -1722,11 +1728,12 @@ libbalsa_identity_config_dialog(GtkWindow *parent, GList **identities,
     dialog =
         gtk_dialog_new_with_buttons(_("Manage Identities"),
                                     parent, /* must NOT be modal */
-                                    GTK_DIALOG_DESTROY_WITH_PARENT,
-                                    GTK_STOCK_HELP, IDENTITY_RESPONSE_HELP,
-                                    GTK_STOCK_NEW, IDENTITY_RESPONSE_NEW,
-                                    GTK_STOCK_REMOVE, IDENTITY_RESPONSE_REMOVE,
-                                    GTK_STOCK_CLOSE, IDENTITY_RESPONSE_CLOSE,
+                                    GTK_DIALOG_DESTROY_WITH_PARENT |
+                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    _("_Help"),   IDENTITY_RESPONSE_HELP,
+                                    _("_New"),    IDENTITY_RESPONSE_NEW,
+                                    _("_Remove"), IDENTITY_RESPONSE_REMOVE,
+                                    _("_Close"),  IDENTITY_RESPONSE_CLOSE,
                                     NULL);
 #if HAVE_MACOSX_DESKTOP
     libbalsa_macosx_menu_for_parent(dialog, parent);
@@ -1876,6 +1883,8 @@ display_frame_update(GObject * dialog, LibBalsaIdentity* ident)
                            ident->x_face, TRUE);
     display_frame_set_boolean(dialog, "identity-requestmdn",
                               ident->request_mdn);
+    display_frame_set_boolean(dialog, "identity-requestdsn",
+                              ident->request_dsn);
 
     display_frame_set_boolean(dialog, "identity-gpgsign",
                               ident->gpg_sign);
@@ -1981,6 +1990,7 @@ libbalsa_identity_new_config(const gchar* name)
     ident->face = libbalsa_conf_get_string("FacePath");
     ident->x_face = libbalsa_conf_get_string("XFacePath");
     ident->request_mdn = libbalsa_conf_get_bool("RequestMDN");
+    ident->request_dsn = libbalsa_conf_get_bool("RequestDSN");
 
     ident->gpg_sign = libbalsa_conf_get_bool("GpgSign");
     ident->gpg_encrypt = libbalsa_conf_get_bool("GpgEncrypt");
@@ -2027,6 +2037,7 @@ libbalsa_identity_save(LibBalsaIdentity* ident, const gchar* group)
     if (ident->x_face)
         libbalsa_conf_set_string("XFacePath", ident->x_face);
     libbalsa_conf_set_bool("RequestMDN", ident->request_mdn);
+    libbalsa_conf_set_bool("RequestDSN", ident->request_dsn);
 
     libbalsa_conf_set_bool("GpgSign", ident->gpg_sign);
     libbalsa_conf_set_bool("GpgEncrypt", ident->gpg_encrypt);
