@@ -160,10 +160,11 @@ lb_gpgme_select_key(const gchar * user_name, gboolean secret, GList * keys,
     /* FIXME: create dialog according to the Gnome HIG */
     dialog = gtk_dialog_new_with_buttons(_("Select key"),
 					 parent,
-					 GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_STOCK_OK, GTK_RESPONSE_OK,
-					 GTK_STOCK_CANCEL,
-					 GTK_RESPONSE_CANCEL, NULL);
+					 GTK_DIALOG_DESTROY_WITH_PARENT |
+                                         GTK_DIALOG_USE_HEADER_BAR,
+                                         _("_OK"),     GTK_RESPONSE_OK,
+                                         _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                         NULL);
 #if HAVE_MACOSX_DESKTOP
     libbalsa_macosx_menu_for_parent(dialog, parent);
 #endif
@@ -181,7 +182,7 @@ lb_gpgme_select_key(const gchar * user_name, gboolean secret, GList * keys,
 				 ("Select the public key for the recipient %s"),
 				 user_name);
     label = gtk_label_new(prompt);
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+    gtk_widget_set_halign(label, GTK_ALIGN_START);
     g_free(prompt);
     gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, TRUE, 0);
 
@@ -343,10 +344,11 @@ get_passphrase_real(const gchar * uid_hint, const gchar * passphrase_info,
 
     /* FIXME: create dialog according to the Gnome HIG */
     dialog = gtk_dialog_new_with_buttons(_("Enter Passphrase"), parent,
-					 GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_STOCK_OK, GTK_RESPONSE_OK,
-					 GTK_STOCK_CANCEL,
-					 GTK_RESPONSE_CANCEL, NULL);
+					 GTK_DIALOG_DESTROY_WITH_PARENT |
+                                         GTK_DIALOG_USE_HEADER_BAR,
+                                         _("_OK"),     GTK_RESPONSE_OK,
+                                         _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                         NULL);
 #if HAVE_MACOSX_DESKTOP
     libbalsa_macosx_menu_for_parent(dialog, parent);
 #endif
