@@ -85,6 +85,12 @@ static gboolean libbalsa_mailbox_local_get_msg_part(LibBalsaMessage *msg,
                                                     GError **err);
 
 static void lbm_local_sort(LibBalsaMailbox * mailbox, GArray *sort_array);
+static guint
+libbalsa_mailbox_local_add_messages(LibBalsaMailbox          * mailbox,
+                                    LibBalsaAddMessageIterator msg_iterator,
+                                    gpointer                   iter_data,
+                                    GError                  ** err);
+
 static GArray *libbalsa_mailbox_local_duplicate_msgnos(LibBalsaMailbox *
                                                        mailbox);
 static gboolean
@@ -169,6 +175,8 @@ libbalsa_mailbox_local_class_init(LibBalsaMailboxLocalClass * klass)
     libbalsa_mailbox_class->get_message_part = 
         libbalsa_mailbox_local_get_msg_part;
     libbalsa_mailbox_class->sort = lbm_local_sort;
+    libbalsa_mailbox_class->add_messages =
+        libbalsa_mailbox_local_add_messages;
     libbalsa_mailbox_class->messages_change_flags =
         libbalsa_mailbox_local_messages_change_flags;
     libbalsa_mailbox_class->msgno_has_flags =
@@ -190,7 +198,7 @@ libbalsa_mailbox_local_init(LibBalsaMailboxLocal * mailbox)
     mailbox->save_tree_id = 0;
 }
 
-GObject *
+LibBalsaMailbox *
 libbalsa_mailbox_local_new(const gchar * path, gboolean create)
 {
     GType magic_type = libbalsa_mailbox_type_from_path(path);
@@ -2168,7 +2176,7 @@ lbm_local_sync_real(LibBalsaMailboxLocal * local)
 static gboolean
 lbm_local_sync_idle(LibBalsaMailboxLocal * local)
 {
-#if 0 && defined(BALSA_USE_THREADS)
+#if defined(BALSA_USE_THREADS)
     pthread_t sync_thread;
 
     pthread_create(&sync_thread, NULL, (void *) lbm_local_sync_real, local);
@@ -2197,7 +2205,8 @@ lbm_local_sync_queue(LibBalsaMailboxLocal * local)
     /* queue sync job so that the delay is at least five times longer
      * than the syncing time. Otherwise large mailbox owners will be
      * annnoyed. */
-    schedule_delay = (local->sync_time*5000)/local->sync_cnt;
+    schedule_delay =
+        local->sync_cnt ? (local->sync_time * 5000) / local->sync_cnt : 0;
     local->sync_id = g_timeout_add_full(G_PRIORITY_LOW, schedule_delay,
                                         (GSourceFunc)lbm_local_sync_idle,
                                         local, NULL);
@@ -2210,6 +2219,34 @@ lbm_local_sort(LibBalsaMailbox * mailbox, GArray *sort_array)
     lbm_local_queue_save_tree(LIBBALSA_MAILBOX_LOCAL(mailbox));
 }
 
+static guint
+libbalsa_mailbox_local_add_messages(LibBalsaMailbox          * mailbox,
+                                    LibBalsaAddMessageIterator msg_iterator,
+                                    gpointer                   iter_data,
+                                    GError                  ** err)
+{
+    LibBalsaMessageFlag flag;
+    GMimeStream *stream;
+    LibBalsaMailboxLocal *local;
+    guint cnt;
+    LibBalsaMailboxLocalAddMessageFunc *add_message;
+
+    local = LIBBALSA_MAILBOX_LOCAL(mailbox);
+    cnt = 0;
+    add_message = LIBBALSA_MAILBOX_LOCAL_GET_CLASS(local)->add_message;
+    while (msg_iterator(&flag, &stream, iter_data)) {
+        gboolean success;
+
+        success = (*add_message)(local, stream, flag, err);
+        g_object_unref(stream);
+        if (!success)
+            break;
+        cnt++;
+    }
+
+    return cnt;
+}
+
 #define FLAGS_REALLY_DIFFER(flags0, flags1) \
         (((flags0 ^ flags1) & LIBBALSA_MESSAGE_FLAGS_REAL) != 0)
 
