@@ -90,15 +90,12 @@ static gboolean libbalsa_mailbox_mbox_sync(LibBalsaMailbox * mailbox,
 /* LibBalsaMailboxLocal class methods */
 static LibBalsaMailboxLocalMessageInfo
     *lbm_mbox_get_info(LibBalsaMailboxLocal * local, guint msgno);
+static LibBalsaMailboxLocalAddMessageFunc lbm_mbox_add_message;
 
 static gboolean
 libbalsa_mailbox_mbox_fetch_message_structure(LibBalsaMailbox * mailbox,
                                               LibBalsaMessage * message,
                                               LibBalsaFetchFlag flags);
-static guint libbalsa_mailbox_mbox_add_messages(LibBalsaMailbox *mailbox,
-						LibBalsaAddMessageIterator m,
-						void *m_arg,
-						GError ** err);
 static guint
 libbalsa_mailbox_mbox_total_messages(LibBalsaMailbox * mailbox);
 #if BALSA_USE_THREADS
@@ -169,7 +166,6 @@ libbalsa_mailbox_mbox_class_init(LibBalsaMailboxMboxClass * klass)
 	libbalsa_mailbox_mbox_close_mailbox;
     libbalsa_mailbox_class->fetch_message_structure =
 	libbalsa_mailbox_mbox_fetch_message_structure;
-    libbalsa_mailbox_class->add_messages = libbalsa_mailbox_mbox_add_messages;
     libbalsa_mailbox_class->total_messages =
 	libbalsa_mailbox_mbox_total_messages;
 #if BALSA_USE_THREADS
@@ -181,6 +177,7 @@ libbalsa_mailbox_mbox_class_init(LibBalsaMailboxMboxClass * klass)
 	libbalsa_mailbox_mbox_remove_files;
 
     libbalsa_mailbox_local_class->get_info = lbm_mbox_get_info;
+    libbalsa_mailbox_local_class->add_message = lbm_mbox_add_message;
     object_class->dispose = libbalsa_mailbox_mbox_dispose;
 }
 
@@ -228,7 +225,7 @@ lbm_mbox_check_files(const gchar * path, gboolean create)
     return 0;
 }
 
-GObject *
+LibBalsaMailbox *
 libbalsa_mailbox_mbox_new(const gchar * path, gboolean create)
 {
     LibBalsaMailbox *mailbox;
@@ -236,14 +233,14 @@ libbalsa_mailbox_mbox_new(const gchar * path, gboolean create)
     mailbox = g_object_new(LIBBALSA_TYPE_MAILBOX_MBOX, NULL);
 
     mailbox->is_directory = FALSE;
-	
+
     if (libbalsa_mailbox_local_set_path(LIBBALSA_MAILBOX_LOCAL(mailbox),
                                         path, create) != 0) {
 	g_object_unref(mailbox);
 	return NULL;
     }
-    
-    return G_OBJECT(mailbox);
+
+    return mailbox;
 }
 
 /* Helper: seek to offset, and return TRUE if the seek succeeds and a
@@ -742,9 +739,6 @@ libbalsa_mailbox_mbox_open(LibBalsaMailbox * mailbox, GError **err)
         lbm_mbox_restore(mbox);
         parse_mailbox(mbox);
     }
-    
-    LIBBALSA_MAILBOX_LOCAL(mailbox)->sync_time = time(NULL) - t0;
-    LIBBALSA_MAILBOX_LOCAL(mailbox)->sync_cnt  = 1;
 
     mbox_unlock(mailbox, gmime_stream);
     libbalsa_mime_stream_shared_unlock(gmime_stream);
@@ -1519,7 +1513,7 @@ libbalsa_mailbox_mbox_sync(LibBalsaMailbox * mailbox, gboolean expunge)
     temp_stream = g_mime_stream_fs_new(i);
 
     for (i = first; i < messages; i++) {
-	guint status_len, x_status_len;
+	gint status_len, x_status_len;
 
 	msg_info = message_info_from_msgno(mbox, i + 1);
 	if (expunge && (msg_info->local_info.flags & LIBBALSA_MESSAGE_FLAG_DELETED))
@@ -1938,11 +1932,12 @@ lbm_mbox_armored_stream(GMimeStream * stream)
 
 /* Called with mailbox locked. */
 static gboolean
-libbalsa_mailbox_mbox_add_message(LibBalsaMailbox * mailbox,
-                                  GMimeStream * stream,
-                                  LibBalsaMessageFlag flags,
-                                  GError ** err)
+lbm_mbox_add_message(LibBalsaMailboxLocal * local,
+                     GMimeStream          * stream,
+                     LibBalsaMessageFlag    flags,
+                     GError              ** err)
 {
+    LibBalsaMailbox *mailbox = (LibBalsaMailbox *) local;
     LibBalsaMessage *message;
     gchar date_string[27];
     gchar *sender;
@@ -1981,7 +1976,7 @@ libbalsa_mailbox_mbox_add_message(LibBalsaMailbox * mailbox,
     from = g_strdup_printf ("From %s %s", address, date_string );
     g_free(address);
     
-    path = libbalsa_mailbox_local_get_path(mailbox);
+    path = libbalsa_mailbox_local_get_path(local);
     /* open in read-write mode */
     fd = open(path, O_RDWR);
     if (fd < 0) {
@@ -2047,27 +2042,6 @@ libbalsa_mailbox_mbox_add_message(LibBalsaMailbox * mailbox,
     return retval >= 0;
 }
 
-static guint
-libbalsa_mailbox_mbox_add_messages(LibBalsaMailbox * mailbox,
-				   LibBalsaAddMessageIterator msg_iterator,
-				   void *arg,
-				   GError **err)
-{
-    LibBalsaMessageFlag flag;
-    GMimeStream *stream;
-
-    guint cnt = 0;
-    while( msg_iterator(&flag, &stream, arg) ) {
-	gboolean success =
-	    libbalsa_mailbox_mbox_add_message(mailbox, stream, flag, err);
-	g_object_unref(stream);
-	if(!success)
-	    break;
-	cnt++;
-    }
-    return cnt;
-}
-
 static guint
 libbalsa_mailbox_mbox_total_messages(LibBalsaMailbox * mailbox)
 {
