@@ -68,6 +68,7 @@ static void lbm_mh_set_path(LibBalsaMailboxLocal * mailbox,
 static void lbm_mh_remove_files(LibBalsaMailboxLocal *mailbox);
 static LibBalsaMailboxLocalMessageInfo
     *lbm_mh_get_info(LibBalsaMailboxLocal * local, guint msgno);
+static LibBalsaMailboxLocalAddMessageFunc lbm_mh_add_message;
 
 static gboolean libbalsa_mailbox_mh_open(LibBalsaMailbox * mailbox,
 					 GError **err);
@@ -85,10 +86,6 @@ static gboolean libbalsa_mailbox_mh_fetch_message_structure(LibBalsaMailbox
                                                             * message,
                                                             LibBalsaFetchFlag
                                                             flags);
-static guint libbalsa_mailbox_mh_add_messages(LibBalsaMailbox * mailbox,
-					      LibBalsaAddMessageIterator m,
-					      void *m_arg,
-					      GError ** err);
 static guint libbalsa_mailbox_mh_total_messages(LibBalsaMailbox * mailbox);
 
 
@@ -146,7 +143,6 @@ libbalsa_mailbox_mh_class_init(LibBalsaMailboxMhClass * klass)
 	libbalsa_mailbox_mh_close_mailbox;
     libbalsa_mailbox_class->fetch_message_structure =
 	libbalsa_mailbox_mh_fetch_message_structure;
-    libbalsa_mailbox_class->add_messages = libbalsa_mailbox_mh_add_messages;
     libbalsa_mailbox_class->total_messages =
 	libbalsa_mailbox_mh_total_messages;
 
@@ -154,6 +150,7 @@ libbalsa_mailbox_mh_class_init(LibBalsaMailboxMhClass * klass)
     libbalsa_mailbox_local_class->set_path     = lbm_mh_set_path;
     libbalsa_mailbox_local_class->remove_files = lbm_mh_remove_files;
     libbalsa_mailbox_local_class->get_info     = lbm_mh_get_info;
+    libbalsa_mailbox_local_class->add_message  = lbm_mh_add_message;
 }
 
 static void
@@ -219,7 +216,7 @@ lbm_mh_set_path(LibBalsaMailboxLocal * local, const gchar * path)
     lbm_mh_set_sequences_filename(LIBBALSA_MAILBOX_MH(local), path);
 }
 
-GObject *
+LibBalsaMailbox *
 libbalsa_mailbox_mh_new(const gchar * path, gboolean create)
 {
     LibBalsaMailbox *mailbox;
@@ -234,7 +231,7 @@ libbalsa_mailbox_mh_new(const gchar * path, gboolean create)
 	return NULL;
     }
 
-    return G_OBJECT(mailbox);
+    return mailbox;
 }
 
 static void
@@ -303,7 +300,6 @@ lbm_mh_remove_files(LibBalsaMailboxLocal *mailbox)
     LIBBALSA_MAILBOX_LOCAL_CLASS(parent_class)->remove_files(mailbox);
 }
 
-#define INVALID_FLAG ((unsigned) -1)
 
 static LibBalsaMailboxLocalMessageInfo *
 lbm_mh_get_info(LibBalsaMailboxLocal * local, guint msgno)
@@ -312,7 +308,7 @@ lbm_mh_get_info(LibBalsaMailboxLocal * local, guint msgno)
 
     msg_info = lbm_mh_message_info_from_msgno(LIBBALSA_MAILBOX_MH(local),
 					      msgno);
-    if (msg_info->local_info.flags == INVALID_FLAG)
+    if (msg_info->local_info.flags == LIBBALSA_MESSAGE_FLAG_INVALID)
         msg_info->local_info.flags = msg_info->orig_flags;
 
     return &msg_info->local_info;
@@ -373,7 +369,7 @@ lbm_mh_parse_mailbox(LibBalsaMailboxMh * mh, gboolean add_msg_info)
 				    GINT_TO_POINTER(fileno));
 	    if (!msg_info) {
 		msg_info = g_new0(struct message_info, 1);
-		msg_info->local_info.flags = INVALID_FLAG;
+		msg_info->local_info.flags = LIBBALSA_MESSAGE_FLAG_INVALID;
 		g_hash_table_insert(mh->messages_info,
 				    GINT_TO_POINTER(fileno), msg_info);
 		g_ptr_array_add(mh->msgno_2_msg_info, msg_info);
@@ -541,8 +537,6 @@ libbalsa_mailbox_mh_open(LibBalsaMailbox * mailbox, GError **err)
     mailbox->unread_messages = 0;
     lbm_mh_parse_both(mh);
 
-    LIBBALSA_MAILBOX_LOCAL(mailbox)->sync_time = 0;
-    LIBBALSA_MAILBOX_LOCAL(mailbox)->sync_cnt  = 1;
 #ifdef DEBUG
     g_print(_("%s: Opening %s Refcount: %d\n"),
 	    "LibBalsaMailboxMh", mailbox->name, mailbox->open_ref);
@@ -759,7 +753,7 @@ static void
 lbm_mh_flag_line(struct message_info *msg_info, LibBalsaMessageFlag flag,
 		 struct line_info *li)
 {
-    if (msg_info->local_info.flags == INVALID_FLAG)
+    if (msg_info->local_info.flags == LIBBALSA_MESSAGE_FLAG_INVALID)
 	msg_info->local_info.flags = msg_info->orig_flags;
     if (!(msg_info->local_info.flags & flag))
 	return;
@@ -832,7 +826,7 @@ libbalsa_mailbox_mh_sync(LibBalsaMailbox * mailbox, gboolean expunge)
     msgno = 1;
     while (msgno <= mh->msgno_2_msg_info->len) {
 	msg_info = lbm_mh_message_info_from_msgno(mh, msgno);
-	if (msg_info->local_info.flags == INVALID_FLAG)
+	if (msg_info->local_info.flags == LIBBALSA_MESSAGE_FLAG_INVALID)
 	    msg_info->local_info.flags = msg_info->orig_flags;
 	if (mailbox->state == LB_MAILBOX_STATE_CLOSING)
 	    msg_info->local_info.flags &= ~LIBBALSA_MESSAGE_FLAG_RECENT;
@@ -874,9 +868,9 @@ libbalsa_mailbox_mh_sync(LibBalsaMailbox * mailbox, gboolean expunge)
 		new_file = g_build_filename(path, tmp, NULL);
 		g_free(tmp);
 
-		if (libbalsa_safe_rename(old_file, new_file) == -1)
+		if (libbalsa_safe_rename(old_file, new_file) == -1) {
 		    /* FIXME: report error ... */
-		    ;
+		}
 
 		g_free(old_file);
 		g_free(new_file);
@@ -1062,10 +1056,10 @@ lbm_mh_update_sequences(LibBalsaMailboxMh * mh, gint fileno,
 
 /* Called with mailbox locked. */
 static gboolean
-libbalsa_mailbox_mh_add_message(LibBalsaMailbox * mailbox,
-                                GMimeStream * stream,
-                                LibBalsaMessageFlag flags,
-                                GError ** err)
+lbm_mh_add_message(LibBalsaMailboxLocal * local,
+                   GMimeStream          * stream,
+                   LibBalsaMessageFlag    flags,
+                   GError              ** err)
 {
     LibBalsaMailboxMh *mh;
     const char *path;
@@ -1077,13 +1071,13 @@ libbalsa_mailbox_mh_add_message(LibBalsaMailbox * mailbox,
     int retries;
     GMimeStream *in_stream;
 
-    mh = LIBBALSA_MAILBOX_MH(mailbox);
+    mh = LIBBALSA_MAILBOX_MH(local);
 
     /* Make sure we know the highest message number: */
     lbm_mh_parse_mailbox(mh, FALSE);
 
     /* open tempfile */
-    path = libbalsa_mailbox_local_get_path(mailbox);
+    path = libbalsa_mailbox_local_get_path(local);
     fd = libbalsa_mailbox_mh_open_temp(path, &tmp);
     if (fd == -1) {
         g_set_error(err, LIBBALSA_MAILBOX_ERROR,
@@ -1154,27 +1148,6 @@ libbalsa_mailbox_mh_add_message(LibBalsaMailbox * mailbox,
     return TRUE;
 }
 
-static guint
-libbalsa_mailbox_mh_add_messages(LibBalsaMailbox * mailbox,
-				 LibBalsaAddMessageIterator msg_iterator,
-				 void *arg,
-				 GError **err)
-{
-    LibBalsaMessageFlag flag;
-    GMimeStream *stream;
-
-    guint cnt = 0;
-    while( msg_iterator(&flag, &stream, arg) ) {
-	gboolean success =
-	    libbalsa_mailbox_mh_add_message(mailbox, stream, flag, err);
-	g_object_unref(stream);
-	if(!success)
-	    break;
-	cnt++;
-    }
-    return cnt;
-}
-
 static guint
 libbalsa_mailbox_mh_total_messages(LibBalsaMailbox * mailbox)
 {
