@@ -71,13 +71,8 @@ static GMimeStream *lbmss_stream_substream(GMimeStream * stream,
                                            gint64 start, gint64 end);
 
 static GMimeStreamFsClass *parent_class = NULL;
-#if GLIB_CHECK_VERSION(2, 32, 0)
 static GMutex lbmss_mutex;
 static GCond lbmss_cond;
-#else                           /* GLIB_CHECK_VERSION(2, 32, 0) */
-static GMutex *lbmss_mutex;
-static GCond *lbmss_cond;
-#endif                          /* GLIB_CHECK_VERSION(2, 32, 0) */
 
 GType
 libbalsa_mime_stream_shared_get_type(void)
@@ -112,10 +107,6 @@ lbmss_stream_class_init(LibBalsaMimeStreamSharedClass * klass)
     GObjectClass *object_class = G_OBJECT_CLASS(klass);
 
     parent_class = g_type_class_ref(GMIME_TYPE_STREAM_FS);
-#if !GLIB_CHECK_VERSION(2, 32, 0)
-    lbmss_mutex  = g_mutex_new();
-    lbmss_cond   = g_cond_new();
-#endif                          /* GLIB_CHECK_VERSION(2, 32, 0) */
 
     object_class->finalize  = lbmss_finalize;
 
@@ -289,21 +280,12 @@ libbalsa_mime_stream_shared_lock(GMimeStream * stream)
     lock = stream_shared->lock;
     thread_self = g_thread_self();
 
-#if GLIB_CHECK_VERSION(2, 32, 0)
     g_mutex_lock(&lbmss_mutex);
     while (lock->count > 0 && lock->thread != thread_self)
         g_cond_wait(&lbmss_cond, &lbmss_mutex);
     ++lock->count;
     lock->thread = thread_self;
     g_mutex_unlock(&lbmss_mutex);
-#else                           /* GLIB_CHECK_VERSION(2, 32, 0) */
-    g_mutex_lock(lbmss_mutex);
-    while (lock->count > 0 && lock->thread != thread_self)
-        g_cond_wait(lbmss_cond, lbmss_mutex);
-    ++lock->count;
-    lock->thread = thread_self;
-    g_mutex_unlock(lbmss_mutex);
-#endif                          /* GLIB_CHECK_VERSION(2, 32, 0) */
 }
 
 /**
@@ -330,17 +312,10 @@ libbalsa_mime_stream_shared_unlock(GMimeStream * stream)
     lock = stream_shared->lock;
     g_return_if_fail(lock->count > 0);
 
-#if GLIB_CHECK_VERSION(2, 32, 0)
     g_mutex_lock(&lbmss_mutex);
     if (--lock->count == 0)
         g_cond_signal(&lbmss_cond);
     g_mutex_unlock(&lbmss_mutex);
-#else                           /* GLIB_CHECK_VERSION(2, 32, 0) */
-    g_mutex_lock(lbmss_mutex);
-    if (--lock->count == 0)
-        g_cond_signal(lbmss_cond);
-    g_mutex_unlock(lbmss_mutex);
-#endif                          /* GLIB_CHECK_VERSION(2, 32, 0) */
 }
 
 #endif                          /* BALSA_USE_THREADS */
