@@ -24,7 +24,7 @@
 # include "config.h"
 #endif                          /* HAVE_CONFIG_H */
 
-#define _BSD_SOURCE     1 
+#define _DEFAULT_SOURCE 1 
 #define _POSIX_C_SOURCE 199309L
 #include "send.h"
 
@@ -245,7 +245,7 @@ send_dialog_destroy_cb(GtkWidget* w)
    ensures that there is send_dialog available.
 */
 static void
-ensure_send_progress_dialog()
+ensure_send_progress_dialog(GtkWindow * parent)
 {
     GtkWidget* label;
     GtkBox *content_box;
@@ -253,10 +253,10 @@ ensure_send_progress_dialog()
     if(send_dialog) return;
 
     send_dialog = gtk_dialog_new_with_buttons(_("Sending Mail..."), 
-                                              NULL,
-                                              GTK_DIALOG_DESTROY_WITH_PARENT,
-                                              _("_Hide"), 
-                                              GTK_RESPONSE_CLOSE,
+                                              parent,
+                                              GTK_DIALOG_DESTROY_WITH_PARENT |
+                                              GTK_DIALOG_USE_HEADER_BAR,
+                                              _("_Hide"), GTK_RESPONSE_CLOSE,
                                               NULL);
     gtk_window_set_wmclass(GTK_WINDOW(send_dialog), "send_dialog", "Balsa");
     label = gtk_label_new(_("Sending Mail..."));
@@ -284,7 +284,7 @@ ensure_send_progress_dialog()
 #define send_unlock() pthread_mutex_unlock(&send_messages_lock);
 
 #else
-#define ensure_send_progress_dialog()
+#define ensure_send_progress_dialog(parent)
 #define send_lock()   
 #define send_unlock() 
 #endif
@@ -477,6 +477,8 @@ libbalsa_message_queue(LibBalsaMessage * message, LibBalsaMailbox * outbox,
     if (fccbox)
         g_mime_object_set_header(GMIME_OBJECT(message->mime_msg), "X-Balsa-Fcc",
                                   fccbox->url);
+    g_mime_object_set_header(GMIME_OBJECT(message->mime_msg), "X-Balsa-DSN",
+			     message->request_dsn ? "1" : "0");
 #if ENABLE_ESMTP
     g_mime_object_set_header(GMIME_OBJECT(message->mime_msg), "X-Balsa-SmtpServer",
 	                      libbalsa_smtp_server_get_name(smtp_server));
@@ -528,13 +530,15 @@ libbalsa_message_queue(LibBalsaMessage * message, LibBalsaMailbox * outbox,
 static gboolean lbs_process_queue(LibBalsaMailbox * outbox,
                                   LibBalsaFccboxFinder finder,
                                   LibBalsaSmtpServer * smtp_server,
-                                  gboolean debug);
+                                  gboolean debug,
+                                  GtkWindow * parent);
 
 LibBalsaMsgCreateResult
 libbalsa_message_send(LibBalsaMessage * message, LibBalsaMailbox * outbox,
                       LibBalsaMailbox * fccbox,
                       LibBalsaFccboxFinder finder,
                       LibBalsaSmtpServer * smtp_server,
+                      GtkWindow * parent,
                       gboolean flow, gboolean debug,
 		      GError ** error)
 {
@@ -548,7 +552,7 @@ libbalsa_message_send(LibBalsaMessage * message, LibBalsaMailbox * outbox,
                                         smtp_server, flow, error);
 
     if (result == LIBBALSA_MESSAGE_CREATE_OK
-        && !lbs_process_queue(outbox, finder, smtp_server, debug))
+        && !lbs_process_queue(outbox, finder, smtp_server, debug, parent))
             return LIBBALSA_MESSAGE_SEND_ERROR;
 
     return result;
@@ -601,7 +605,8 @@ libbalsa_message_cb (void **buf, int *len, void *arg)
 
 static void
 add_recipients(smtp_message_t message,
-               InternetAddressList * recipient_list)
+               InternetAddressList * recipient_list,
+               gboolean request_dsn)
 {
     const InternetAddress *ia;
     int i;
@@ -612,14 +617,24 @@ add_recipients(smtp_message_t message,
     for (i = 0; i < internet_address_list_length (recipient_list); i++) {
         ia = internet_address_list_get_address (recipient_list, i);
 
-	if (INTERNET_ADDRESS_IS_MAILBOX (ia))
-	    smtp_add_recipient (message, INTERNET_ADDRESS_MAILBOX (ia)->addr);
-	else
-	    add_recipients(message, INTERNET_ADDRESS_GROUP (ia)->members);
+	if (INTERNET_ADDRESS_IS_MAILBOX (ia)) {
+	    smtp_recipient_t recipient;
 
-            /* XXX  - this is where to add DSN requests.  It would be
-               cool if LibBalsaAddress could contain DSN options
-               for a particular recipient. */
+            recipient =
+                smtp_add_recipient(message,
+                                   INTERNET_ADDRESS_MAILBOX(ia)->addr);
+	    if (request_dsn) {
+                smtp_dsn_set_notify(recipient,
+                                    Notify_SUCCESS | Notify_FAILURE |
+                                    Notify_DELAY);
+
+		/* XXX  - It would be cool if LibBalsaAddress could contain DSN options
+	           for a particular recipient.  For the time being, just use a switch */
+	    }
+	} else {
+            add_recipients(message, INTERNET_ADDRESS_GROUP(ia)->members,
+                           request_dsn);
+	}
     }
 }
 
@@ -634,7 +649,8 @@ add_recipients(smtp_message_t message,
  */
 static gboolean
 lbs_process_queue(LibBalsaMailbox * outbox, LibBalsaFccboxFinder finder,
-		  LibBalsaSmtpServer * smtp_server, gboolean debug)
+		  LibBalsaSmtpServer * smtp_server, gboolean debug,
+                  GtkWindow * parent)
 {
     LibBalsaServer *server = LIBBALSA_SERVER(smtp_server);
     MessageQueueItem *new_message;
@@ -658,7 +674,7 @@ lbs_process_queue(LibBalsaMailbox * outbox, LibBalsaFccboxFinder finder,
 	return TRUE;
     }
     /* We create here the progress bar */
-    ensure_send_progress_dialog();
+    ensure_send_progress_dialog(parent);
 
     /* Create the libESMTP session.  Loop over the out box and add the
        messages to the session. */
@@ -671,7 +687,7 @@ lbs_process_queue(LibBalsaMailbox * outbox, LibBalsaFccboxFinder finder,
     g_free(host_with_port);
 
     /* Tell libESMTP how to use the SMTP STARTTLS extension.  */
-    smtp_starttls_enable (session, server->tls_mode);
+    smtp_starttls_enable (session, (enum starttls_option) server->tls_mode);
 
     /* Now tell libESMTP it can use the SMTP AUTH extension.  */
     smtp_auth_set_context(session,
@@ -708,6 +724,8 @@ lbs_process_queue(LibBalsaMailbox * outbox, LibBalsaFccboxFinder finder,
             g_object_unref(msg);
             continue;
         }
+        msg->request_dsn =
+        	(atoi(libbalsa_message_get_user_header(msg, "X-Balsa-DSN")) != 0);
 
 	new_message = msg_queue_item_new(finder);
         created = libbalsa_fill_msg_queue_item_from_queu(msg, new_message);
@@ -780,6 +798,11 @@ lbs_process_queue(LibBalsaMailbox * outbox, LibBalsaFccboxFinder finder,
 	    /* Add this after the Bcc: copy. */
 	    message = smtp_add_message (session);
 
+	    if (msg->request_dsn) {
+		smtp_dsn_set_ret(message, Ret_HDRS);
+		smtp_dsn_set_envid(message, msg->message_id);
+	    }
+
             /* The main copy must not contain a Bcc: header, unless the
              * message has no To: recipients and no Cc: recipients, and
              * exactly one Bcc: recipient: */
@@ -860,11 +883,11 @@ lbs_process_queue(LibBalsaMailbox * outbox, LibBalsaFccboxFinder finder,
 	       the Bcc recipient list, when it has more than one address.
 	       The bcc copy gets the single Bcc recipient.  */
 
-            add_recipients(message, msg->headers->to_list);
-            add_recipients(message, msg->headers->cc_list);
+            add_recipients(message, msg->headers->to_list, msg->request_dsn);
+            add_recipients(message, msg->headers->cc_list, msg->request_dsn);
 
             add_recipients(bcc_message ? bcc_message : message, 
-                           msg->headers->bcc_list);
+                           msg->headers->bcc_list, msg->request_dsn);
 
 	    /* Prohibit status headers. */
 	    smtp_set_header_option(message, "Status", Hdr_PROHIBIT, 1);
@@ -929,12 +952,13 @@ gboolean
 libbalsa_process_queue(LibBalsaMailbox * outbox,
                        LibBalsaFccboxFinder finder,
                        GSList * smtp_servers,
+                       GtkWindow * parent,
 		       gboolean debug)
 {
     for (; smtp_servers; smtp_servers = smtp_servers->next) {
         LibBalsaSmtpServer *smtp_server =
 		LIBBALSA_SMTP_SERVER(smtp_servers->data);
-        if (!lbs_process_queue(outbox, finder, smtp_server, debug))
+        if (!lbs_process_queue(outbox, finder, smtp_server, debug, parent))
             return FALSE;
     }
 
@@ -1235,7 +1259,7 @@ libbalsa_smtp_event_cb_serial(smtp_session_t session, int event_no,
 */
 gboolean 
 libbalsa_process_queue(LibBalsaMailbox* outbox, LibBalsaFccboxFinder finder,
-                       gboolean debug)
+                       gboolean debug, GtkWindow * parent)
 {
     MessageQueueItem *mqi = NULL, *new_message;
     SendMessageInfo *send_message_info;
@@ -1254,7 +1278,7 @@ libbalsa_process_queue(LibBalsaMailbox* outbox, LibBalsaFccboxFinder finder,
     sending_threads++;
 #endif
 
-    ensure_send_progress_dialog();
+    ensure_send_progress_dialog(parent);
     if (!libbalsa_mailbox_open(outbox, NULL)) {
 #ifdef BALSA_USE_THREADS
 	sending_threads--;
@@ -1619,7 +1643,7 @@ balsa_send_message_real(SendMessageInfo* info)
 
 
 static void
-message_add_references(LibBalsaMessage * message, GMimeMessage * msg)
+message_add_references(const LibBalsaMessage * message, GMimeMessage * msg)
 {
     /* If the message has references set, add them to the envelope */
     if (message->references != NULL) {
@@ -2027,29 +2051,50 @@ libbalsa_message_postpone(LibBalsaMessage * message,
 static void
 libbalsa_set_message_id(GMimeMessage * mime_message)
 {
-    struct utsname utsbuf;
-    const gchar *host = "localhost";
+    static GMutex mutex;	/* as to make me thread-safe... */
+    static GRand *rand = NULL;
+    static struct {
+	gint64 now_monotonic;
+	gdouble randval;
+	char user_name[16];
+	char host_name[16];
+    } id_data;
+    GHmac *msg_id_hash;
+    guint8 buffer[32];
+    gsize buflen;
     gchar *message_id;
-#ifdef _GNU_SOURCE
-    gchar *fqdn;
-    const gchar *domain = "localdomain";
 
-    /* In an ideal world, uname() allows us to make a FQDN. */
-    if (uname(&utsbuf) == 0) {
-	if (*utsbuf.nodename)
-	    host = utsbuf.nodename;
-	if (*utsbuf.domainname)
-	    domain = utsbuf.domainname;
+    g_mutex_lock(&mutex);
+    if (rand == NULL) {
+	/* initialise some stuff on first-time use... */
+	rand = g_rand_new_with_seed((guint32) time(NULL));
+	strncpy(id_data.user_name, g_get_user_name(),
+                sizeof(id_data.user_name));
+	strncpy(id_data.host_name, g_get_host_name(),
+                sizeof(id_data.host_name));
     }
-    fqdn = g_strconcat(host, ".", domain, NULL);
-    message_id = g_mime_utils_generate_message_id(fqdn);
-    g_free(fqdn);
-#else				/* _GNU_SOURCE */
 
-    if (uname(&utsbuf) == 0 && *utsbuf.nodename)
-	host = utsbuf.nodename;
-    message_id = g_mime_utils_generate_message_id(host);
-#endif				/* _GNU_SOURCE */
+    /* get some randomness... */
+    id_data.now_monotonic = g_get_monotonic_time();
+    id_data.randval = g_rand_double(rand);
+
+    /* hash the buffer */
+    msg_id_hash =
+        g_hmac_new(G_CHECKSUM_SHA256, (const guchar *) &id_data,
+                   sizeof(id_data));
+    buflen = sizeof(buffer);
+    g_hmac_get_digest(msg_id_hash, buffer, &buflen);
+    g_hmac_unref(msg_id_hash);
+    g_mutex_unlock(&mutex);
+
+    /* create a msg id string
+     * Note: RFC 5322, sect. 3.6.4 explicitly allows the form
+     *    dot-atom-text "@" dot-atom-text
+     * where dot-atom-text may include all base64 (RFC 1421) chars,
+     * including '+' and '/' */
+    message_id = g_base64_encode(buffer, buflen);
+    memmove(message_id + 23, message_id + 22, strlen(message_id) - 23);
+    message_id[22] = '@';
 
     g_mime_message_set_message_id(mime_message, message_id);
     g_free(message_id);
@@ -2089,6 +2134,8 @@ libbalsa_fill_msg_queue_item_from_queu(LibBalsaMessage * message,
                                     "X-Balsa-Fcc");
         g_mime_object_remove_header(GMIME_OBJECT(message->mime_msg),
                                     "X-Balsa-SmtpServer");
+        g_mime_object_remove_header(GMIME_OBJECT(message->mime_msg),
+                                    "X-Balsa-DSN");
 	mqi->stream = g_mime_stream_mem_new();
         libbalsa_mailbox_lock_store(message->mailbox);
 	g_mime_object_write_to_stream(GMIME_OBJECT(message->mime_msg),
