@@ -417,7 +417,8 @@ smtp_server_response(GtkDialog * dialog, gint response,
     switch (response) {
     case GTK_RESPONSE_HELP:
         screen = gtk_widget_get_screen(GTK_WIDGET(dialog));
-        gtk_show_uri(screen, "ghelp:balsa?smtp-server-config",
+        gtk_show_uri(screen,
+                     "help:preferences-mail-options#smtp-server-config",
                      gtk_get_current_event_time(), &error);
         if (error) {
             libbalsa_information(LIBBALSA_INFORMATION_WARNING,
@@ -442,13 +443,13 @@ smtp_server_response(GtkDialog * dialog, gint response,
 #if HAVE_SMTP_TLS_CLIENT_CERTIFICATE
         switch (gtk_combo_box_get_active(GTK_COMBO_BOX(sdi->tlsm))) {
         case 0:
-            server->tls_mode = Starttls_DISABLED;
+            server->tls_mode = LIBBALSA_TLS_DISABLED;
             break;
         case 1:
-            server->tls_mode = Starttls_ENABLED;
+            server->tls_mode = LIBBALSA_TLS_ENABLED;
             break;
         case 2:
-            server->tls_mode = Starttls_REQUIRED;
+            server->tls_mode = LIBBALSA_TLS_REQUIRED;
             break;
         default:
             break;
@@ -538,10 +539,11 @@ libbalsa_smtp_server_dialog(LibBalsaSmtpServer * smtp_server,
     sdi->dialog = dialog =
         gtk_dialog_new_with_buttons(_("SMTP Server"),
                                     parent,
-                                    GTK_DIALOG_DESTROY_WITH_PARENT,
-                                    GTK_STOCK_OK, GTK_RESPONSE_OK,
-                                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                    GTK_STOCK_HELP, GTK_RESPONSE_HELP,
+                                    GTK_DIALOG_DESTROY_WITH_PARENT |
+                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    _("_OK"),     GTK_RESPONSE_OK,
+                                    _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                    _("_Help"),   GTK_RESPONSE_HELP,
                                     NULL);
 #if HAVE_MACOSX_DESKTOP
     libbalsa_macosx_menu_for_parent(dialog, parent);
