@@ -28,6 +28,7 @@
 
 #include <stdio.h>
 
+#include "application-helpers.h"
 #include "misc.h"
 #include "libbalsa.h"
 #include "libbalsa_private.h"
@@ -35,66 +36,31 @@
 #include "macosx-helpers.h"
 #include <glib/gi18n.h>
 
-static void close_cb(GtkAction * action, gpointer data);
-static void copy_cb(GtkAction * action, gpointer data);
-static void select_all_cb(GtkAction * action, gpointer data);
-static void lsv_escape_cb(GtkAction * action, gpointer data);
+typedef struct {
+    LibBalsaMessage *msg;
+    GtkWidget *text;
+    GtkWidget *window;
+    gboolean *escape_specials;
+    gint *width;
+    gint *height;
+} LibBalsaSourceViewerInfo;
 
-/* Normal items */
-static GtkActionEntry entries[] = {
-    /* Top level */
-    {"FileMenu", NULL, N_("_File")},
-    {"EditMenu", NULL, N_("_Edit")},
-    {"ViewMenu", NULL, N_("_View")},
-    /* Items */
-    {"Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
-     N_("Close the window"), G_CALLBACK(close_cb)},
-    {"Copy", GTK_STOCK_COPY, N_("_Copy"), "<control>C",
-     N_("Copy text"), G_CALLBACK(copy_cb)},
-    {"Select", NULL, N_("_Select Text"), "<control>A",
-     N_("Select entire mail"), G_CALLBACK(select_all_cb)},
-};
-
-/* Toggle items */
-static GtkToggleActionEntry toggle_entries[] = {
-    {"Escape", NULL, N_("_Escape Special Characters"), NULL,
-     N_("Escape special and non-ASCII characters"),
-     G_CALLBACK(lsv_escape_cb), FALSE}
-};
-
-static const char *ui_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='FileMenu'>"
-"      <menuitem action='Close'/>"
-"    </menu>"
-"    <menu action='EditMenu'>"
-"      <menuitem action='Copy'/>"
-"      <separator/>"
-"      <menuitem action='Select'/>"
-"    </menu>"
-"    <menu action='ViewMenu'>"
-"      <menuitem action='Escape'/>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-
-static void 
-select_all_cb(GtkAction * action, gpointer data)
+static void
+lsv_close_activated(GSimpleAction * action,
+                    GVariant      * parameter,
+                    gpointer        user_data)
 {
-    GtkTextView *text = g_object_get_data(G_OBJECT(data), "text");
-    GtkTextBuffer *buffer = gtk_text_view_get_buffer(text);
-    GtkTextIter start, end;
-
-    gtk_text_buffer_get_bounds(buffer, &start, &end);
-    gtk_text_buffer_move_mark_by_name(buffer, "insert", &start);
-    gtk_text_buffer_move_mark_by_name(buffer, "selection_bound", &end);
+    gtk_widget_destroy(GTK_WIDGET(user_data));
 }
 
 static void
-copy_cb(GtkAction * action, gpointer data)
+lsv_copy_activated(GSimpleAction * action,
+                   GVariant      * parameter,
+                   gpointer        user_data)
 {
-    GtkTextView *text = g_object_get_data(G_OBJECT(data), "text");
+    LibBalsaSourceViewerInfo *lsvi =
+        g_object_get_data(G_OBJECT(user_data), "lsvi");
+    GtkTextView *text = GTK_TEXT_VIEW(lsvi->text);
     GtkTextBuffer *buffer = gtk_text_view_get_buffer(text);
     GdkDisplay *display;
     GtkClipboard *clipboard;
@@ -106,25 +72,24 @@ copy_cb(GtkAction * action, gpointer data)
 }
 
 static void
-close_cb(GtkAction * action, gpointer data)
+lsv_select_activated(GSimpleAction * action,
+                     GVariant      * parameter,
+                     gpointer        user_data)
 {
-    gtk_widget_destroy(GTK_WIDGET(data));
+    LibBalsaSourceViewerInfo *lsvi =
+        g_object_get_data(G_OBJECT(user_data), "lsvi");
+    GtkTextView *text = GTK_TEXT_VIEW(lsvi->text);
+    GtkTextBuffer *buffer = gtk_text_view_get_buffer(text);
+    GtkTextIter start, end;
+
+    gtk_text_buffer_get_bounds(buffer, &start, &end);
+    gtk_text_buffer_move_mark_by_name(buffer, "insert", &start);
+    gtk_text_buffer_move_mark_by_name(buffer, "selection_bound", &end);
 }
 
-struct _LibBalsaSourceViewerInfo {
-    LibBalsaMessage *msg;
-    GtkWidget *text;
-    GtkWidget *window;
-    gboolean *escape_specials;
-    gint *width;
-    gint *height;
-};
-
-typedef struct _LibBalsaSourceViewerInfo LibBalsaSourceViewerInfo;
-
 static void
 lsv_show_message(const char *message, LibBalsaSourceViewerInfo * lsvi,
-		      gboolean escape)
+                 gboolean escape)
 {
     GtkTextBuffer *buffer;
     GtkTextIter start;
@@ -149,10 +114,12 @@ lsv_show_message(const char *message, LibBalsaSourceViewerInfo * lsvi,
 }
 
 static void
-lsv_escape_cb(GtkAction * action, gpointer data)
+lsv_escape_change_state(GSimpleAction * action,
+                        GVariant      * state,
+                        gpointer        user_data)
 {
     LibBalsaSourceViewerInfo *lsvi =
-        g_object_get_data(G_OBJECT(data), "lsvi");
+        g_object_get_data(G_OBJECT(user_data), "lsvi");
     LibBalsaMessage *msg = lsvi->msg;
     GMimeStream *msg_stream;
     GMimeStream *mem_stream;
@@ -175,14 +142,23 @@ lsv_escape_cb(GtkAction * action, gpointer data)
     g_mime_stream_write(mem_stream, "", 1); /* close string */
     raw_message = (char *) GMIME_STREAM_MEM(mem_stream)->buffer->data;
 
-    *(lsvi->escape_specials) =
-	gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(action));
+    *(lsvi->escape_specials) = g_variant_get_boolean(state);
     lsv_show_message(raw_message, lsvi, *(lsvi->escape_specials));
 
     g_object_unref(msg_stream);
     g_object_unref(mem_stream);
+
+    g_simple_action_set_state(action, state);
 }
 
+static GActionEntry win_entries[] = {
+    {"lsv-close",  lsv_close_activated},
+    {"lsv-copy",   lsv_copy_activated},
+    {"lsv-select", lsv_select_activated},
+    {"lsv-escape", libbalsa_toggle_activated, NULL, "false",
+        lsv_escape_change_state}
+};
+
 static void
 lsv_window_destroy_notify(LibBalsaSourceViewerInfo * lsvi)
 {
@@ -194,47 +170,6 @@ lsv_window_destroy_notify(LibBalsaSourceViewerInfo * lsvi)
    pops up a window containing the source of the message msg.
 */
 
-static GtkWidget*
-lbsv_app_set_menus(GtkWindow * app, GtkAction ** action)
-{
-    GtkWidget *window;
-    GtkWidget *menubar;
-    GtkActionGroup *action_group;
-    GtkUIManager *ui_manager;
-    GtkAccelGroup *accel_group;
-    GError *error = NULL;
-
-    window = GTK_WIDGET(app);
-
-    action_group = gtk_action_group_new("MenuActions");
-    gtk_action_group_set_translation_domain(action_group, NULL);
-
-    gtk_action_group_add_actions(action_group, entries,
-                                 G_N_ELEMENTS(entries), window);
-    gtk_action_group_add_toggle_actions(action_group, toggle_entries,
-                                        G_N_ELEMENTS(toggle_entries),
-                                        window);
-
-    ui_manager = gtk_ui_manager_new();
-    gtk_ui_manager_insert_action_group(ui_manager, action_group, 0);
-
-    accel_group = gtk_ui_manager_get_accel_group(ui_manager);
-    gtk_window_add_accel_group(GTK_WINDOW(window), accel_group);
-
-    if (!gtk_ui_manager_add_ui_from_string(ui_manager, ui_description,
-                                           -1, &error)) {
-        g_message("building menus failed: %s", error->message);
-        g_error_free(error);
-        return NULL;
-    }
-
-    menubar = gtk_ui_manager_get_widget(ui_manager, "/MainMenu");
-
-    *action =
-        gtk_ui_manager_get_action(ui_manager, "/MainMenu/ViewMenu/Escape");
-    return menubar;
-}
-
 static void
 lsv_size_allocate_cb(GtkWindow * window, GtkAllocation * alloc,
                      LibBalsaSourceViewerInfo * lsvi)
@@ -249,27 +184,43 @@ lsv_size_allocate_cb(GtkWindow * window, GtkAllocation * alloc,
     }
 }
 
+#define BALSA_SOURCE_VIEWER "balsa-source-viewer"
+
 void
-libbalsa_show_message_source(LibBalsaMessage* msg, const gchar * font,
-			     gboolean* escape_specials,
-                             gint * width, gint * height)
+libbalsa_show_message_source(GtkApplication  * application,
+                             LibBalsaMessage * msg,
+                             const gchar     * font,
+			     gboolean        * escape_specials,
+                             gint            * width,
+                             gint            * height)
 {
     GtkWidget *text;
-    PangoFontDescription *desc;
+    gchar *css;
+    GtkCssProvider *css_provider;
     GtkWidget *vbox, *interior;
     GtkWidget *window;
-    GtkAction *escape_action = NULL;
+    gchar *ui_file;
+    GtkWidget *menu_bar;
+    GError *err = NULL;
     LibBalsaSourceViewerInfo *lsvi;
-    GtkWidget *menubar;
+    GAction *escape_action;
 
     g_return_if_fail(msg);
     g_return_if_fail(MAILBOX_OPEN(msg->mailbox));
 
     text = gtk_text_view_new();
 
-    desc = pango_font_description_from_string(font);
-    gtk_widget_override_font(text, desc);
-    pango_font_description_free(desc);
+    gtk_widget_set_name(text, BALSA_SOURCE_VIEWER);
+    css = g_strconcat("#" BALSA_SOURCE_VIEWER " {font:", font, "}", NULL);
+
+    css_provider = gtk_css_provider_new();
+    gtk_css_provider_load_from_data(css_provider, css, -1, NULL);
+    g_free(css);
+
+    gtk_style_context_add_provider(gtk_widget_get_style_context(text) ,
+                                   GTK_STYLE_PROVIDER(css_provider),
+                                   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    g_object_unref(css_provider);
 
     gtk_text_view_set_editable(GTK_TEXT_VIEW(text), FALSE);
     gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(text), GTK_WRAP_WORD_CHAR);
@@ -280,20 +231,34 @@ libbalsa_show_message_source(LibBalsaMessage* msg, const gchar * font,
                                    GTK_POLICY_ALWAYS);
     gtk_container_add(GTK_CONTAINER(interior), GTK_WIDGET(text));
 
-    window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+    window = gtk_application_window_new(application);
     gtk_window_set_title(GTK_WINDOW(window), _("Message Source"));
-    g_object_set_data(G_OBJECT(window), "text", text);
     gtk_window_set_wmclass(GTK_WINDOW(window), "message-source", "Balsa");
     gtk_window_set_default_size(GTK_WINDOW(window), *width, *height);
+
+    ui_file = g_build_filename(BALSA_DATA_PREFIX, "ui", "source-viewer.ui",
+                               NULL);
+    menu_bar = libbalsa_window_get_menu_bar(GTK_APPLICATION_WINDOW(window),
+                                            win_entries,
+                                            G_N_ELEMENTS(win_entries),
+                                            ui_file, &err, window);
+    if (!menu_bar) {
+        libbalsa_information(LIBBALSA_INFORMATION_WARNING,
+                             _("Error adding from %s: %s\n"), ui_file,
+                             err->message);
+        g_free(ui_file);
+        g_error_free(err);
+        return;
+    }
+    g_free(ui_file);
+
     vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 1);
-    menubar = lbsv_app_set_menus(GTK_WINDOW(window), &escape_action);
-    
 #if HAVE_MACOSX_DESKTOP
-    libbalsa_macosx_menu(window, GTK_MENU_SHELL(menubar));
+    libbalsa_macosx_menu(window, GTK_MENU_SHELL(menu_bar));
 #else
-    gtk_box_pack_start(GTK_BOX(vbox), menubar, FALSE, TRUE, 1);
+    gtk_box_pack_start(GTK_BOX(vbox), menu_bar, FALSE, TRUE, 1);
 #endif
-    
+
     gtk_box_pack_start(GTK_BOX(vbox), interior, TRUE, TRUE, 0);
     gtk_container_add(GTK_CONTAINER(window), vbox);
 
@@ -311,9 +276,10 @@ libbalsa_show_message_source(LibBalsaMessage* msg, const gchar * font,
                      G_CALLBACK(lsv_size_allocate_cb), lsvi);
 
     gtk_widget_show_all(window);
-    if (*escape_specials)
-        gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(escape_action),
-                                     TRUE);
-    else
-        lsv_escape_cb(escape_action, window);
+
+    escape_action =
+        g_action_map_lookup_action(G_ACTION_MAP(window), "lsv-escape");
+    lsv_escape_change_state(G_SIMPLE_ACTION(escape_action),
+                            g_variant_new_boolean(*escape_specials),
+                            window);
 }
