@@ -116,31 +116,35 @@ GtkWidget *
 balsa_ab_window_new(gboolean composing, GtkWindow* parent)
 {
     GtkWidget *ret;
+    BalsaAbWindow *ab;
 
-    ret = g_object_new(BALSA_TYPE_AB_WINDOW, NULL);
-    g_return_val_if_fail(ret, NULL);
+    ret = g_object_new(BALSA_TYPE_AB_WINDOW,
+                       "use-header-bar", TRUE,
+                       "transient-for", parent,
+                       NULL);
+    g_return_val_if_fail(ret != NULL, NULL);
+    ab = (BalsaAbWindow *) ret;
 
-    BALSA_AB_WINDOW(ret)->composing = composing;
+    ab->composing = composing;
 
     if ( composing ) {
 	gtk_dialog_add_buttons(GTK_DIALOG(ret),
-                               GTK_STOCK_OK,     GTK_RESPONSE_OK,
-                               GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                               _("_OK"),     GTK_RESPONSE_OK,
+                               _("_Cancel"), GTK_RESPONSE_CANCEL,
                                NULL);
-	gtk_widget_show(GTK_WIDGET(BALSA_AB_WINDOW(ret)->send_to_label));
-	gtk_widget_show(GTK_WIDGET(BALSA_AB_WINDOW(ret)->send_to_list));
-	gtk_widget_show(GTK_WIDGET(BALSA_AB_WINDOW(ret)->arrow_box));
+	gtk_widget_show(ab->send_to_label);
+	gtk_widget_show(ab->send_to_list);
+	gtk_widget_show(ab->arrow_box);
     } else {
 	gtk_dialog_add_buttons(GTK_DIALOG(ret),
-                               GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                               _("_Close"), GTK_RESPONSE_CLOSE,
                                NULL);
-	gtk_widget_hide(GTK_WIDGET(BALSA_AB_WINDOW(ret)->send_to_label));
-	gtk_widget_hide(GTK_WIDGET(BALSA_AB_WINDOW(ret)->send_to_list));
-	gtk_widget_hide(GTK_WIDGET(BALSA_AB_WINDOW(ret)->arrow_box));
+	gtk_widget_hide(ab->send_to_label);
+	gtk_widget_hide(ab->send_to_list);
+	gtk_widget_hide(ab->arrow_box);
     }
-    if(parent) gtk_window_set_transient_for(GTK_WINDOW(ret), parent);
-    return ret;
 
+    return ret;
 }
 
 static GtkWidget *
@@ -311,15 +315,13 @@ balsa_ab_window_init(BalsaAbWindow *ab)
     gtk_grid_attach(GTK_GRID(grid), hbox, 0, 2, 1, 1);
     gtk_widget_show(GTK_WIDGET(hbox));
 
-    w = balsa_stock_button_with_label(GTK_STOCK_OPEN,
-                                      _("Run Editor"));
+    w = gtk_button_new_with_mnemonic(_("Run _Editor"));
     g_signal_connect(w, "clicked",
                      G_CALLBACK(balsa_ab_window_run_editor), NULL);
     gtk_container_add(GTK_CONTAINER(hbox), w);
     gtk_widget_show(GTK_WIDGET(w));
 
-    w = balsa_stock_button_with_label(GTK_STOCK_ADD,
-                                      _("_Re-Import"));
+    w = gtk_button_new_with_mnemonic(_("_Re-Import"));
     g_signal_connect(G_OBJECT(w), "clicked",
                      G_CALLBACK(balsa_ab_window_reload),
 		       ab);
@@ -335,14 +337,16 @@ balsa_ab_window_init(BalsaAbWindow *ab)
     gtk_grid_attach(GTK_GRID(grid), ab->arrow_box, 1, 1, 1, 1);
     gtk_widget_show(ab->arrow_box);
 
-    w = balsa_stock_button_with_label(GTK_STOCK_GO_FORWARD, "");
+    w = gtk_button_new_from_icon_name("go-next-symbolic",
+                                      GTK_ICON_SIZE_BUTTON);
     gtk_box_pack_start(GTK_BOX(ab->arrow_box), w, TRUE, FALSE, 0);
     gtk_widget_show(w);
     g_signal_connect(G_OBJECT(w), "clicked",
 		     G_CALLBACK(balsa_ab_window_move_to_recipient_list),
 		       ab);
 
-    w = balsa_stock_button_with_label(GTK_STOCK_GO_BACK, "");
+    w = gtk_button_new_from_icon_name("go-previous-symbolic",
+                                      GTK_ICON_SIZE_BUTTON);
     gtk_box_pack_start(GTK_BOX(ab->arrow_box), w, TRUE, FALSE, 0);
     gtk_widget_show(w);
     g_signal_connect(G_OBJECT(w), "clicked",
