@@ -175,7 +175,7 @@ add_radio_buttons(GtkWidget * grid, gint row, AddressBookConfig * abc)
     GtkWidget *button;
 
     label = gtk_label_new(_("Suggest complete addresses:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+    gtk_widget_set_halign(label, GTK_ALIGN_START);
     gtk_grid_attach(GTK_GRID(grid), label, 0, row, 2, 1);
 
     abc->as_i_type =
@@ -223,20 +223,20 @@ create_local_dialog(AddressBookConfig * abc, const gchar * type)
     ab = abc->address_book;
     if (ab) {
         title = g_strdup_printf(_("Modify %s Address Book"), type);
-        action = GTK_STOCK_APPLY;
+        action = _("_Apply");
         name = ab->name;
     } else {
         title = g_strdup_printf(_("Add %s Address Book"), type);
-        action = GTK_STOCK_ADD;
+        action = _("_Add");
         name = NULL;
     }
 
     dialog =
         gtk_file_chooser_dialog_new(title, abc->parent,
                                     GTK_FILE_CHOOSER_ACTION_SAVE,
-                                    GTK_STOCK_HELP, GTK_RESPONSE_HELP,
-                                    action, GTK_RESPONSE_APPLY,
-                                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                    _("_Help"),   GTK_RESPONSE_HELP,
+                                    action,       GTK_RESPONSE_APPLY,
+                                    _("_Cancel"), GTK_RESPONSE_CANCEL,
                                     NULL);
     g_free(title);
 #if HAVE_MACOSX_DESKTOP
@@ -324,17 +324,18 @@ create_generic_dialog(AddressBookConfig * abc, const gchar * type)
     ab = abc->address_book;
     if (ab) {
         title = g_strdup_printf(_("Modify %s Address Book"), type);
-        action = GTK_STOCK_APPLY;
+        action = _("_Apply");
     } else {
         title = g_strdup_printf(_("Add %s Address Book"), type);
-        action = GTK_STOCK_ADD;
+        action = _("_Add");
     }
 
     dialog =
-        gtk_dialog_new_with_buttons(title, abc->parent, 0,
-                                    GTK_STOCK_HELP, GTK_RESPONSE_HELP,
+        gtk_dialog_new_with_buttons(title, abc->parent,
+                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    _("_Help"), GTK_RESPONSE_HELP,
                                     action, GTK_RESPONSE_APPLY,
-                                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                    _("_Cancel"), GTK_RESPONSE_CANCEL,
                                     NULL);
     g_free(title);
 #if HAVE_MACOSX_DESKTOP
@@ -370,7 +371,7 @@ create_externq_dialog(AddressBookConfig * abc)
 				   label);
 
     label = gtk_label_new(_("Load program location:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
+    gtk_widget_set_halign(label, GTK_ALIGN_END);
     gtk_grid_attach(GTK_GRID(grid), label, 0, 1, 1, 1);
     abc->ab_specific.externq.load =
         gtk_file_chooser_button_new
@@ -383,7 +384,7 @@ create_externq_dialog(AddressBookConfig * abc)
                                   abc->ab_specific.externq.load);
 
     label = gtk_label_new(_("Save program location:"));
-    gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+    gtk_widget_set_halign(label, GTK_ALIGN_START);
     gtk_grid_attach(GTK_GRID(grid), label, 0, 2, 1, 1);
     abc->ab_specific.externq.save =
         gtk_file_chooser_button_new
@@ -527,7 +528,7 @@ help_button_cb(AddressBookConfig * abc)
     GError *err = NULL;
 
     screen = gtk_widget_get_screen(abc->window);
-    gtk_show_uri(screen, "ghelp:balsa?preferences-address-books",
+    gtk_show_uri(screen, "help:balsa/preferences-address-books",
                  gtk_get_current_event_time(), &err);
 
     if (err) {
