@@ -23,6 +23,7 @@
 # include "config.h"
 #endif                          /* HAVE_CONFIG_H */
 #include "balsa-app.h"
+#include "balsa-icons.h"
 
 #include <string.h>
 #include <stdlib.h>
@@ -86,9 +87,10 @@ ask_password_real(LibBalsaServer * server, LibBalsaMailbox * mbox)
 
     dialog = gtk_dialog_new_with_buttons(_("Password needed"),
                                          GTK_WINDOW(balsa_app.main_window),
-                                         GTK_DIALOG_DESTROY_WITH_PARENT,
-                                         GTK_STOCK_OK, GTK_RESPONSE_OK,
-                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                         GTK_DIALOG_DESTROY_WITH_PARENT |
+                                         GTK_DIALOG_USE_HEADER_BAR,
+                                         _("_OK"), GTK_RESPONSE_OK,
+                                         _("_Cancel"), GTK_RESPONSE_CANCEL,
                                          NULL); 
 #if HAVE_MACOSX_DESKTOP
     libbalsa_macosx_menu_for_parent(dialog, GTK_WINDOW(balsa_app.main_window));
@@ -360,6 +362,7 @@ balsa_app_init(void)
     balsa_app.quote_regex = g_strdup(DEFAULT_QUOTE_REGEX);
 
     /* font */
+    balsa_app.use_system_fonts = TRUE;
     balsa_app.message_font = NULL;
     balsa_app.subject_font = NULL;
 
@@ -425,9 +428,6 @@ balsa_app_init(void)
     /* Message filing */
     balsa_app.folder_mru=NULL;
     balsa_app.fcc_mru=NULL;
-
-    g_object_set(gtk_settings_get_for_screen(gdk_screen_get_default()),
-                 "gtk-fallback-icon-theme", "gnome", NULL);
 }
 
 void
@@ -579,29 +579,6 @@ balsa_add_open_mailbox_urls(GPtrArray * url_array)
                                 append_url_if_open, url_array);
 }
 
-GtkWidget *
-balsa_stock_button_with_label(const char *icon, const char *text)
-{
-    GtkWidget *button;
-    GtkWidget *pixmap = gtk_image_new_from_stock(icon, GTK_ICON_SIZE_BUTTON);
-    GtkWidget *align = gtk_alignment_new(0.5, 0.5, 0, 0);
-    GtkWidget *hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
-
-    button = gtk_button_new();
-    gtk_container_add(GTK_CONTAINER(button), align);
-    gtk_container_add(GTK_CONTAINER(align), hbox);
-
-    gtk_box_pack_start(GTK_BOX(hbox), pixmap, FALSE, FALSE, 0);
-    if (text && *text) {
-        GtkWidget *label = gtk_label_new_with_mnemonic(text);
-        gtk_label_set_mnemonic_widget(GTK_LABEL(label), button);
-        gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
-    }
-
-    gtk_widget_show_all(button);
-    return button;
-}
-
 /* 
  * Utilities for searching a GNode tree of BalsaMailboxNodes
  *
