@@ -136,6 +136,8 @@ enum _MwActionAfterMove {
 
 /* global balsa application structure */
 extern struct BalsaApplication {
+    GtkApplication *application;
+
     /* personal information */
     GList* identities;
     LibBalsaIdentity* current_ident;
@@ -313,7 +315,8 @@ extern struct BalsaApplication {
     GList *open_mailbox_list;  /* data is a pointer to the mailbox */
     gchar *current_mailbox_url;/* remember for next session */
     
-    /* font used to display messages */
+    /* fonts */
+    gboolean use_system_fonts;
     gchar *message_font;
     gchar *subject_font;
 
@@ -396,8 +399,6 @@ void balsa_app_destroy(void);
 void update_timer(gboolean update, guint minutes);
 
 gchar *ask_password(LibBalsaServer * server, LibBalsaMailbox * mbox);
-GtkWidget *balsa_stock_button_with_label(const char *icon,
-					 const char *label);
 void balsa_open_mailbox_list(gchar ** urls);
 
 /* Search functions */
