@@ -122,7 +122,6 @@ static void bndx_drag_cb(GtkWidget* widget,
 static GtkWidget* bndx_popup_menu_create(BalsaIndex * index);
 static void bndx_do_popup(BalsaIndex * index, GdkEventButton * event);
 static GtkWidget *create_stock_menu_item(GtkWidget * menu,
-                                         const gchar * type,
                                          const gchar * label,
                                          GCallback cb, gpointer data);
 
@@ -1319,8 +1318,6 @@ balsa_index_set_column_widths(BalsaIndex * index)
 {
     GtkTreeView *tree_view = GTK_TREE_VIEW(index);
     gint icon_w;
-    GdkScreen *screen;
-    GtkSettings *settings;
 
 #if defined(TREE_VIEW_FIXED_HEIGHT)
     /* so that fixed width works properly */
@@ -1330,10 +1327,7 @@ balsa_index_set_column_widths(BalsaIndex * index)
 #endif
     /* I have no idea why we must add 5 pixels to the icon width - otherwise,
        the icon will be clipped... */
-    screen = gtk_widget_get_screen(GTK_WIDGET(index));
-    settings = gtk_settings_get_for_screen(screen);
-    gtk_icon_size_lookup_for_settings(settings, GTK_ICON_SIZE_MENU,
-                                      &icon_w, NULL);
+    gtk_icon_size_lookup(GTK_ICON_SIZE_MENU, &icon_w, NULL);
     gtk_tree_view_column_set_fixed_width(gtk_tree_view_get_column
                                          (tree_view, LB_MBOX_MARKED_COL),
                                          icon_w + 5);
@@ -1478,7 +1472,8 @@ bndx_view_source(gpointer data)
 
         if (!message)
             continue;
-	libbalsa_show_message_source(message, balsa_app.message_font,
+	libbalsa_show_message_source(balsa_app.application,
+                                     message, balsa_app.message_font,
 				     &balsa_app.source_escape_specials,
                                      &balsa_app.source_width,
                                      &balsa_app.source_height);
@@ -1558,8 +1553,9 @@ bndx_compose_foreach(BalsaIndex * index, SendType send_type)
             g_assert_not_reached();
             sm = NULL; /** silence invalid warnings */
         }
-        g_signal_connect(G_OBJECT(sm->window), "destroy",
-                         G_CALLBACK(sendmsg_window_destroy_cb), NULL);
+        if (sm)
+            g_signal_connect(G_OBJECT(sm->window), "destroy",
+                             G_CALLBACK(sendmsg_window_destroy_cb), NULL);
     }
     balsa_index_selected_msgnos_free(index, selected);
 }
@@ -1811,7 +1807,7 @@ mru_menu_cb(const gchar * url, BalsaIndex * index)
 static GtkWidget *
 bndx_popup_menu_create(BalsaIndex * index)
 {
-    const static struct {       /* this is a invariable part of */
+    static const struct {       /* this is a invariable part of */
         const char *icon, *label;       /* the context message menu.    */
         GCallback func;
     } entries[] = {
@@ -1836,35 +1832,31 @@ bndx_popup_menu_create(BalsaIndex * index)
     menu = gtk_menu_new();
 
     for (i = 0; i < ELEMENTS(entries); i++)
-        create_stock_menu_item(menu, entries[i].icon, _(entries[i].label),
+        create_stock_menu_item(menu, _(entries[i].label),
                                entries[i].func, index);
 
     gtk_menu_shell_append(GTK_MENU_SHELL(menu),
                           gtk_separator_menu_item_new());
     index->delete_item =
-        create_stock_menu_item(menu, GTK_STOCK_DELETE,
-                               _("_Delete"),
+        create_stock_menu_item(menu, _("_Delete"),
                                G_CALLBACK(bi_toggle_deleted_cb),
                                index);
     index->undelete_item =
-        create_stock_menu_item(menu, GTK_STOCK_UNDELETE,
-                               _("_Undelete"),
+        create_stock_menu_item(menu, _("_Undelete"),
                                G_CALLBACK(bi_toggle_deleted_cb),
                                index);
     index->move_to_trash_item =
-        create_stock_menu_item(menu, GTK_STOCK_DELETE,
-                               _("Move To _Trash"),
+        create_stock_menu_item(menu, _("Move To _Trash"),
                                G_CALLBACK
                                (balsa_message_move_to_trash), index);
 
     menuitem = gtk_menu_item_new_with_mnemonic(_("T_oggle"));
     index->toggle_item = menuitem;
     submenu = gtk_menu_new();
-    create_stock_menu_item(submenu, BALSA_PIXMAP_INFO_FLAGGED,
-                           _("_Flagged"),
+    create_stock_menu_item(submenu, _("_Flagged"),
                            G_CALLBACK(bi_toggle_flagged_cb),
                            index);
-    create_stock_menu_item(submenu, BALSA_PIXMAP_INFO_NEW, _("_Unread"),
+    create_stock_menu_item(submenu, _("_Unread"),
                            G_CALLBACK(bi_toggle_new_cb),
                            index);
 
@@ -1879,8 +1871,7 @@ bndx_popup_menu_create(BalsaIndex * index)
 
     gtk_menu_shell_append(GTK_MENU_SHELL(menu),
                           gtk_separator_menu_item_new());
-    create_stock_menu_item(menu, BALSA_PIXMAP_BOOK_OPEN,
-                           _("_View Source"),
+    create_stock_menu_item(menu, _("_View Source"),
                            G_CALLBACK(bndx_view_source),
                            index);
 
@@ -1994,14 +1985,10 @@ bndx_do_popup(BalsaIndex * index, GdkEventButton * event)
 }
 
 static GtkWidget *
-create_stock_menu_item(GtkWidget * menu, const gchar * type,
-		       const gchar * label, GCallback cb,
+create_stock_menu_item(GtkWidget * menu, const gchar * label, GCallback cb,
 		       gpointer data)
 {
-    GtkWidget *menuitem = gtk_image_menu_item_new_with_mnemonic(label);
-    GtkWidget *image = gtk_image_new_from_stock(type, GTK_ICON_SIZE_MENU);
-
-    gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuitem), image);
+    GtkWidget *menuitem = gtk_menu_item_new_with_mnemonic(label);
 
     g_signal_connect_swapped(G_OBJECT(menuitem), "activate",
                              G_CALLBACK(cb), data);
@@ -2654,9 +2641,10 @@ balsa_index_pipe(BalsaIndex * index)
     info->dialog = dialog =
         gtk_dialog_new_with_buttons(_("Pipe message through a program"),
                                     GTK_WINDOW(balsa_app.main_window),
-                                    GTK_DIALOG_DESTROY_WITH_PARENT,
+                                    GTK_DIALOG_DESTROY_WITH_PARENT |
+                                    GTK_DIALOG_USE_HEADER_BAR,
                                     _("_Run"), GTK_RESPONSE_OK,
-                                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                    _("_Cancel"), GTK_RESPONSE_CANCEL,
                                     NULL);
 #if HAVE_MACOSX_DESKTOP
     libbalsa_macosx_menu_for_parent(dialog, GTK_WINDOW(balsa_app.main_window));
