@@ -29,6 +29,10 @@
 #include "libbalsa.h"
 #include "balsa-app.h"
 
+#if GTK_CHECK_VERSION(3, 10, 0)
+#define BALSA_USE_GTK_STACK
+#endif                          /* GTK_CHECK_VERSION(3, 10, 0) */
+
 #ifdef __cplusplus
 extern "C" {
 #endif				/* __cplusplus */
@@ -54,7 +58,14 @@ typedef enum {
 } BalsaMessageFocusState;
 
 struct _BalsaMessage {
+#ifndef BALSA_USE_GTK_STACK
 	GtkNotebook parent;
+#else /* BALSA_USE_GTK_STACK */
+        GtkBox parent;
+
+        GtkWidget *stack;
+        GtkWidget *switcher;
+#endif /* BALSA_USE_GTK_STACK */
 
         /* Top-level MIME widget */
         BalsaMimeWidget *bm_widget;
@@ -79,8 +90,6 @@ struct _BalsaMessage {
 
 	LibBalsaMessage *message;
 
-	gboolean close_with_msg;
-
         BalsaMessageFocusState focus_state;
 
         /* Find-in-message stuff */
@@ -112,8 +121,6 @@ struct _BalsaMessageClass {
 
 GType balsa_message_get_type(void);
 GtkWidget *balsa_message_new(void);
-void balsa_message_set_close(BalsaMessage * bmessage,
-			     gboolean close_with_msg);
 
 gboolean balsa_message_set(BalsaMessage * bmessage,
 			   LibBalsaMailbox * mailbox, guint msgno);
