@@ -61,6 +61,7 @@ balsa_mime_widget_signature_widget(LibBalsaMessageBody * mime_body,
 {
     gchar *infostr;
     GtkWidget *vbox, *label;
+    GtkWidget *expander;
 
     if (!mime_body->sig_info ||
 	mime_body->sig_info->status == GPG_ERR_NOT_SIGNED)
@@ -85,7 +86,7 @@ balsa_mime_widget_signature_widget(LibBalsaMessageBody * mime_body,
     gtk_container_set_border_width(GTK_CONTAINER(vbox), BMW_CONTAINER_BORDER);
     label = gtk_label_new(infostr);
     gtk_label_set_selectable(GTK_LABEL(label), TRUE);
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+    gtk_widget_set_halign(label, GTK_ALIGN_START);
     gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
     g_free(infostr);
 #ifdef HAVE_GPG
@@ -108,7 +109,10 @@ balsa_mime_widget_signature_widget(LibBalsaMessageBody * mime_body,
     }
 #endif /* HAVE_GPG */
 
-    return vbox;
+    expander = gtk_expander_new(_("Digital Signature"));
+    gtk_container_add(GTK_CONTAINER(expander), vbox);
+
+    return expander;
 }
 
 
@@ -126,17 +130,20 @@ balsa_mime_widget_crypto_frame(LibBalsaMessageBody * mime_body, GtkWidget * chil
     gtk_container_add(GTK_CONTAINER(frame), vbox);
     icon_box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BMW_VBOX_SPACE);
     if (was_encrypted)
-	gtk_box_pack_start(GTK_BOX(icon_box),
-			   gtk_image_new_from_stock(BALSA_PIXMAP_ENCR, GTK_ICON_SIZE_MENU),
-			   FALSE, FALSE, 0);
+        gtk_box_pack_start(GTK_BOX(icon_box),
+                           gtk_image_new_from_icon_name
+                           (balsa_icon_id(BALSA_PIXMAP_ENCR),
+                            GTK_ICON_SIZE_MENU),
+                           FALSE, FALSE, 0);
     if (!no_signature) {
 	const gchar * icon_name =
 	    balsa_mime_widget_signature_icon_name(libbalsa_message_body_protect_state(mime_body));
 	if (!icon_name)
 	    icon_name = BALSA_PIXMAP_SIGN;
-	gtk_box_pack_start(GTK_BOX(icon_box),
-			   gtk_image_new_from_stock(icon_name, GTK_ICON_SIZE_MENU),
-			   FALSE, FALSE, 0);
+        gtk_box_pack_start(GTK_BOX(icon_box),
+                           gtk_image_new_from_icon_name
+                           (balsa_icon_id(icon_name), GTK_ICON_SIZE_MENU),
+                           FALSE, FALSE, 0);
     }
     gtk_frame_set_label_widget(GTK_FRAME(frame), icon_box);
     gtk_container_set_border_width(GTK_CONTAINER(vbox), BMW_MESSAGE_PADDING);
