@@ -82,6 +82,11 @@ static void add_header_sigstate(GtkGrid * grid,
 				GMimeGpgmeSigstat * siginfo);
 #endif
 
+static void bmw_message_set_headers(BalsaMessage        * bm,
+                                    BalsaMimeWidget     * mw,
+                                    LibBalsaMessageBody * part,
+                                    gboolean              show_all_headers);
+
 BalsaMimeWidget *
 balsa_mime_widget_new_message(BalsaMessage * bm,
 			      LibBalsaMessageBody * mime_body,
@@ -134,7 +139,17 @@ balsa_mime_widget_new_message(BalsaMessage * bm,
         mw->header_widget = emb_hdrs = bm_header_widget_new(bm, NULL);
 	gtk_box_pack_start(GTK_BOX(mw->container), emb_hdrs, FALSE, FALSE, 0);
 
-	balsa_mime_widget_message_set_headers(bm, mw, mime_body);
+        bmw_message_set_headers(bm, mw, mime_body,
+                                bm->shown_headers == HEADERS_ALL);
+    } else if (!g_ascii_strcasecmp("text/rfc822-headers", content_type)) {
+	mw = g_object_new(BALSA_TYPE_MIME_WIDGET, NULL);
+	mw->widget = gtk_frame_new(_("message headers"));
+	mw->header_widget = bm_header_widget_new(bm, NULL);
+        gtk_widget_set_valign(mw->header_widget, GTK_ALIGN_START);
+        gtk_widget_set_vexpand(mw->header_widget, FALSE);
+        g_object_set(G_OBJECT(mw->header_widget), "margin", 5, NULL);
+	gtk_container_add(GTK_CONTAINER(mw->widget), mw->header_widget);
+	bmw_message_set_headers(bm, mw, mime_body, TRUE);
     }
 
     /* return the created widget (may be NULL) */
@@ -354,6 +369,8 @@ extbody_send_mail(GtkWidget * button, LibBalsaMessageBody * mime_body)
     result = libbalsa_message_send(message, balsa_app.outbox, NULL,
 				   balsa_find_sentbox_by_url,
 				   balsa_app.current_ident->smtp_server,
+                                   GTK_WINDOW(gtk_widget_get_toplevel
+                                              (button)),
 				   FALSE, balsa_app.debug, &err);
 #else
     result = libbalsa_message_send(message, balsa_app.outbox, NULL,
@@ -441,9 +458,13 @@ static GtkWidget *
 bm_header_widget_new(BalsaMessage * bm, GtkWidget * const * buttons)
 {
     GtkWidget *grid;
+#ifdef GTK_INFO_BAR_WRAPPING_IS_BROKEN
+    GtkWidget *hbox;
+#else                           /* GTK_INFO_BAR_WRAPPING_IS_BROKEN */
     GtkWidget *info_bar_widget;
     GtkInfoBar *info_bar;
     GtkWidget *content_area;
+#endif                          /* GTK_INFO_BAR_WRAPPING_IS_BROKEN */
     GtkWidget *action_area;
     GtkWidget *widget;
 
@@ -458,12 +479,28 @@ bm_header_widget_new(BalsaMessage * bm, GtkWidget * const * buttons)
     g_signal_connect(grid, "key_press_event",
 		     G_CALLBACK(balsa_mime_widget_key_press_event), bm);
 
+#ifdef GTK_INFO_BAR_WRAPPING_IS_BROKEN
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+    gtk_container_add(GTK_CONTAINER(hbox), grid);
+    gtk_container_set_border_width(GTK_CONTAINER(hbox), 6);
+
+    action_area = gtk_button_box_new(GTK_ORIENTATION_VERTICAL);
+    gtk_button_box_set_layout(GTK_BUTTON_BOX(action_area),
+                              GTK_BUTTONBOX_START);
+    gtk_box_pack_end(GTK_BOX(hbox), action_area, FALSE, TRUE, 0);
+#else                           /* GTK_INFO_BAR_WRAPPING_IS_BROKEN */
     info_bar_widget = gtk_info_bar_new();
     info_bar = GTK_INFO_BAR(info_bar_widget);
+
     content_area = gtk_info_bar_get_content_area(info_bar);
     gtk_container_add(GTK_CONTAINER(content_area), grid);
 
     action_area = gtk_info_bar_get_action_area(info_bar);
+    gtk_orientable_set_orientation(GTK_ORIENTABLE(action_area),
+                                   GTK_ORIENTATION_VERTICAL);
+    gtk_button_box_set_layout(GTK_BUTTON_BOX(action_area),
+                              GTK_BUTTONBOX_START);
+#endif                          /* GTK_INFO_BAR_WRAPPING_IS_BROKEN */
     if (!bm->face_box) {
         bm->face_box = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_add(GTK_CONTAINER(action_area), bm->face_box);
@@ -479,7 +516,11 @@ bm_header_widget_new(BalsaMessage * bm, GtkWidget * const * buttons)
 
     widget = gtk_frame_new(NULL);
     gtk_frame_set_shadow_type(GTK_FRAME(widget), GTK_SHADOW_IN);
+#ifdef GTK_INFO_BAR_WRAPPING_IS_BROKEN
+    gtk_container_add(GTK_CONTAINER(widget), hbox);
+#else                           /* GTK_INFO_BAR_WRAPPING_IS_BROKEN */
     gtk_container_add(GTK_CONTAINER(widget), info_bar_widget);
+#endif                          /* GTK_INFO_BAR_WRAPPING_IS_BROKEN */
 
     g_object_set_data(G_OBJECT(widget), BALSA_MESSAGE_GRID, grid);
 
@@ -515,18 +556,18 @@ expanded_cb(GtkExpander * expander, GParamSpec * arg1, GtkLabel * label)
     }
 }
 
+#define BALSA_MESSAGE_HEADER "balsa-message-header"
+
 static void
-add_header_gchar(BalsaMessage * bm, GtkGrid * grid,
-		 const gchar * header, const gchar * label,
-		 const gchar * value)
+add_header_gchar(GtkGrid * grid, const gchar * header, const gchar * label,
+		 const gchar * value, gboolean show_all_headers)
 {
     gint row;
+    gchar *css;
+    GtkCssProvider *css_provider;
     GtkWidget *lab;
-    PangoAttrList *attr_list;
-    PangoFontDescription *font_desc;
-    PangoAttribute *attr;
 
-    if (!(bm->shown_headers == HEADERS_ALL ||
+    if (!(show_all_headers ||
 	  libbalsa_find_word(header, balsa_app.selected_headers)))
 	return;
 
@@ -534,20 +575,34 @@ add_header_gchar(BalsaMessage * bm, GtkGrid * grid,
     while (gtk_grid_get_child_at(grid, 0, row))
         row++;
 
-    attr_list = pango_attr_list_new();
-    font_desc =
-        pango_font_description_from_string(strcmp(header, "subject") ?
-                                           balsa_app.message_font :
-                                           balsa_app.subject_font);
-    attr = pango_attr_font_desc_new(font_desc);
-    pango_font_description_free(font_desc);
-    pango_attr_list_insert(attr_list, attr);
+    if (balsa_app.use_system_fonts) {
+        if (strcmp(header, "subject") == 0)
+            /* Use bold for the subject line */
+            css = g_strdup("#" BALSA_MESSAGE_HEADER " {font-weight:bold}");
+        else
+            css = g_strdup("");
+    } else {
+        css =
+            g_strconcat("#" BALSA_MESSAGE_HEADER " {font:",
+                        strcmp(header, "subject")
+                        ? balsa_app.message_font
+                        : balsa_app.subject_font, "}", NULL);
+    }
+
+    css_provider = gtk_css_provider_new();
+    gtk_css_provider_load_from_data(css_provider, css, -1, NULL);
+    g_free(css);
 
     lab = gtk_label_new(label);
-    gtk_label_set_attributes(GTK_LABEL(lab), attr_list);
+    gtk_widget_set_name(lab, BALSA_MESSAGE_HEADER);
+    gtk_style_context_add_provider(gtk_widget_get_style_context(lab) ,
+                                   GTK_STYLE_PROVIDER(css_provider),
+                                   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
     gtk_grid_attach(grid, lab, 0, row, 1, 1);
     gtk_label_set_selectable(GTK_LABEL(lab), TRUE);
-    gtk_misc_set_alignment(GTK_MISC(lab), 0, 0);
+    gtk_widget_set_halign(lab, GTK_ALIGN_START);
+    gtk_widget_set_valign(lab, GTK_ALIGN_START);
     gtk_widget_show(lab);
 
     if (value && *value != '\0') {
@@ -561,17 +616,28 @@ add_header_gchar(BalsaMessage * bm, GtkGrid * grid,
         lab = gtk_label_new(sanitized);
         g_free(sanitized);
 
-        gtk_label_set_attributes(GTK_LABEL(lab), attr_list);
+        gtk_widget_set_name(lab, BALSA_MESSAGE_HEADER);
+        gtk_style_context_add_provider(gtk_widget_get_style_context(lab) ,
+                                       GTK_STYLE_PROVIDER(css_provider),
+                                       GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
         gtk_label_set_line_wrap_mode(GTK_LABEL(lab), PANGO_WRAP_WORD_CHAR);
         gtk_label_set_selectable(GTK_LABEL(lab), TRUE);
-        gtk_misc_set_alignment(GTK_MISC(lab), 0, 0);
+#if GTK_CHECK_VERSION(3, 16, 0)
+        gtk_label_set_xalign((GtkLabel *) lab, 0.0);
+#else                           /* GTK_CHECK_VERSION(3, 16, 0) */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+        gtk_misc_set_alignment((GtkMisc *) lab, 0.0, 0.0);
+G_GNUC_END_IGNORE_DEPRECATIONS
+#endif                          /* GTK_CHECK_VERSION(3, 16, 0) */
+        gtk_widget_set_halign(lab, GTK_ALIGN_START);
         gtk_widget_set_hexpand(lab, TRUE);
 
         expander = gtk_expander_new(NULL);
         g_signal_connect(expander, "notify::expanded",
                          G_CALLBACK(expanded_cb), lab);
 
-        if(bm->shown_headers == HEADERS_ALL) {
+        if(show_all_headers) {
             gtk_label_set_line_wrap(GTK_LABEL(lab), TRUE);
             gtk_expander_set_expanded(GTK_EXPANDER(expander), TRUE);
         } else {
@@ -588,7 +654,7 @@ add_header_gchar(BalsaMessage * bm, GtkGrid * grid,
         gtk_grid_attach(grid, hbox, 1, row, 1, 1);
     }
 
-    pango_attr_list_unref(attr_list);
+    g_object_unref(css_provider);
 }
 
 static void
@@ -607,7 +673,7 @@ add_header_address_list(BalsaMessage * bm, GtkGrid * grid,
 
     value = internet_address_list_to_string(list, FALSE);
 
-    add_header_gchar(bm, grid, header, label, value);
+    add_header_gchar(grid, header, label, value, FALSE);
 
     g_free(value);
 }
@@ -624,30 +690,13 @@ foreach_label(GtkWidget * widget, LibBalsaMessageBody * part)
                          G_CALLBACK(bm_header_extend_popup), part);
 }
 
-void
-balsa_mime_widget_message_set_headers(BalsaMessage * bm, BalsaMimeWidget *mw,
-				      LibBalsaMessageBody * part)
-{
-    GtkWidget *widget;
-    GtkGrid *grid;
-
-    balsa_mime_widget_message_set_headers_d(bm, mw, part->embhdrs, part->parts,
-                                            part->embhdrs
-                                            ? part->embhdrs->subject
-                                            : NULL );
-    if (!(widget = mw->header_widget))
-	return;
-    grid = bm_header_widget_get_grid(widget);
-    gtk_container_foreach(GTK_CONTAINER(grid), (GtkCallback) foreach_label,
-                          part);
-}
-
-void
-balsa_mime_widget_message_set_headers_d(BalsaMessage * bm,
-                                        BalsaMimeWidget *mw,
-                                        LibBalsaMessageHeaders *headers,
-                                        LibBalsaMessageBody *part,
-                                        const gchar *subject)
+static void
+bmw_message_set_headers_d(BalsaMessage           * bm,
+                          BalsaMimeWidget        * mw,
+                          LibBalsaMessageHeaders * headers,
+                          LibBalsaMessageBody    * part,
+                          const gchar            * subject,
+                          gboolean                 show_all_headers)
 {
     GtkGrid *grid;
     GList *p;
@@ -663,8 +712,9 @@ balsa_mime_widget_message_set_headers_d(BalsaMessage * bm,
 
     if (!headers) {
         /* Gmail sometimes fails to do that. */
-        add_header_gchar(bm, grid, "subject", _("Error:"),
-                         _("IMAP server did not report message structure"));
+        add_header_gchar(grid, "subject", _("Error:"),
+                         _("IMAP server did not report message structure"),
+                         show_all_headers);
         return;
     }
 
@@ -676,24 +726,26 @@ balsa_mime_widget_message_set_headers_d(BalsaMessage * bm,
 
     bm->tab_position = 0;
 
-    add_header_gchar(bm, grid, "subject", _("Subject:"), subject);
+    add_header_gchar(grid, "subject", _("Subject:"), subject,
+                     show_all_headers);
 
     date = libbalsa_message_headers_date_to_utf8(headers,
 						 balsa_app.date_string);
-    add_header_gchar(bm, grid, "date", _("Date:"), date);
+    add_header_gchar(grid, "date", _("Date:"), date, show_all_headers);
     g_free(date);
 
     if (headers->from) {
 	gchar *from =
 	    internet_address_list_to_string(headers->from, FALSE);
-	add_header_gchar(bm, grid, "from", _("From:"), from);
+	add_header_gchar(grid, "from", _("From:"), from, show_all_headers);
 	g_free(from);
     }
 
     if (headers->reply_to) {
 	gchar *reply_to =
 	    internet_address_list_to_string(headers->reply_to, FALSE);
-	add_header_gchar(bm, grid, "reply-to", _("Reply-To:"), reply_to);
+	add_header_gchar(grid, "reply-to", _("Reply-To:"), reply_to,
+                         show_all_headers);
 	g_free(reply_to);
     }
     add_header_address_list(bm, grid, "to", _("To:"), headers->to_list);
@@ -702,14 +754,16 @@ balsa_mime_widget_message_set_headers_d(BalsaMessage * bm,
 
 #if BALSA_SHOW_FCC_AS_WELL_AS_X_BALSA_FCC
     if (headers->fcc_url)
-	add_header_gchar(bm, grid, "fcc", _("Fcc:"), headers->fcc_url);
+	add_header_gchar(grid, "fcc", _("Fcc:"), headers->fcc_url,
+                         show_all_headers);
 #endif
 
     if (headers->dispnotify_to) {
 	gchar *mdn_to =
 	    internet_address_list_to_string(headers->dispnotify_to, FALSE);
-	add_header_gchar(bm, grid, "disposition-notification-to",
-			 _("Disposition-Notification-To:"), mdn_to);
+	add_header_gchar(grid, "disposition-notification-to",
+			 _("Disposition-Notification-To:"), mdn_to,
+                         show_all_headers);
 	g_free(mdn_to);
     }
 
@@ -719,7 +773,7 @@ balsa_mime_widget_message_set_headers_d(BalsaMessage * bm,
 	gchar *hdr;
 
 	hdr = g_strconcat(pair[0], ":", NULL);
-	add_header_gchar(bm, grid, pair[0], hdr, pair[1]);
+	add_header_gchar(grid, pair[0], hdr, pair[1], show_all_headers);
 	g_free(hdr);
     }
 
@@ -740,6 +794,44 @@ balsa_mime_widget_message_set_headers_d(BalsaMessage * bm,
 #endif
 }
 
+static void
+bmw_message_set_headers(BalsaMessage        * bm,
+                        BalsaMimeWidget     * mw,
+                        LibBalsaMessageBody * part,
+                        gboolean              show_all_headers)
+{
+    GtkWidget *widget;
+    GtkGrid *grid;
+
+    bmw_message_set_headers_d(bm, mw, part->embhdrs, part->parts,
+                              part->embhdrs ? part->embhdrs->subject : NULL,
+                              show_all_headers);
+    if (!(widget = mw->header_widget))
+	return;
+    grid = bm_header_widget_get_grid(widget);
+    gtk_container_foreach(GTK_CONTAINER(grid), (GtkCallback) foreach_label,
+                          part);
+}
+
+void
+balsa_mime_widget_message_set_headers(BalsaMessage        * bm,
+                                      BalsaMimeWidget     * mw,
+                                      LibBalsaMessageBody * part)
+{
+    bmw_message_set_headers(bm, mw, part,
+                            bm->shown_headers == HEADERS_ALL);
+}
+
+void
+balsa_mime_widget_message_set_headers_d(BalsaMessage           * bm,
+                                        BalsaMimeWidget        * mw,
+                                        LibBalsaMessageHeaders * headers,
+                                        LibBalsaMessageBody    * part,
+                                        const gchar            * subject)
+{
+    bmw_message_set_headers_d(bm, mw, headers, part, subject,
+                              bm->shown_headers == HEADERS_ALL);
+}
 
 #ifdef HAVE_GPGME
 /*
@@ -755,7 +847,7 @@ add_header_sigstate(GtkGrid * grid, GMimeGpgmeSigstat * siginfo)
     gint row;
 
     format = siginfo->status ==
-        GPG_ERR_NO_ERROR ? "<i>%s%s</i>" : "<b><i>%s%s</i><b>";
+        GPG_ERR_NO_ERROR ? "<i>%s%s</i>" : "<b><i>%s%s</i></b>";
     msg = g_markup_printf_escaped
         (format,
          libbalsa_gpgme_sig_protocol_name(siginfo->protocol),
@@ -764,7 +856,7 @@ add_header_sigstate(GtkGrid * grid, GMimeGpgmeSigstat * siginfo)
     label = gtk_label_new(NULL);
     gtk_label_set_markup(GTK_LABEL(label), msg);
     g_free(msg);
-    gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
+    gtk_widget_set_halign(label, GTK_ALIGN_START);
     gtk_widget_show(label);
 
     row = 0;
