@@ -153,12 +153,6 @@ balsa_mime_widget_new_text(BalsaMessage * bm, LibBalsaMessageBody * mime_body,
         BalsaMimeWidget *html_widget = NULL;
 
 #ifdef HAVE_HTML_WIDGET
-	/* Force vertical scrollbar while we render the html, otherwise
-	 * the widget will make itself too wide to accept one, forcing
-	 * otherwise unnecessary horizontal scrolling. */
-        gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(bm->scroll),
-                                       GTK_POLICY_AUTOMATIC,
-                                       GTK_POLICY_ALWAYS);
         html_widget = bm_widget_new_html(bm, mime_body);
 #endif
         return html_widget;
@@ -199,7 +193,8 @@ balsa_mime_widget_new_text(BalsaMessage * bm, LibBalsaMessageBody * mime_body,
     gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(mw->widget), GTK_WRAP_WORD_CHAR);
 
     /* set the message font */
-    bm_modify_font_from_string(mw->widget, balsa_app.message_font);
+    if (!balsa_app.use_system_fonts)
+        bm_modify_font_from_string(mw->widget, balsa_app.message_font);
 
     if (libbalsa_message_body_is_flowed(mime_body)) {
 	/* Parse, but don't wrap. */
@@ -288,7 +283,7 @@ create_text_widget(const char * content_type)
     widget = gtk_source_view_new_with_buffer(buffer);
     g_object_unref(buffer);
     return widget;
-#elif (HAVE_GTKSOURCEVIEW == 2)
+#elif (HAVE_GTKSOURCEVIEW > 1)
     static GtkSourceLanguageManager * lm = NULL;
     static const gchar * const * lm_ids = NULL;
     GtkWidget * widget = NULL;
@@ -339,13 +334,25 @@ create_text_widget(const char * content_type)
 #endif
 }
 
+#define BALSA_MESSAGE_TEXT_HEADER "balsa-message-text-header"
+
 static void
 bm_modify_font_from_string(GtkWidget * widget, const char *font)
 {
-    PangoFontDescription *desc =
-        pango_font_description_from_string(balsa_app.message_font);
-    gtk_widget_override_font(widget, desc);
-    pango_font_description_free(desc);
+    gchar *css;
+    GtkCssProvider *css_provider;
+
+    gtk_widget_set_name(widget, BALSA_MESSAGE_TEXT_HEADER);
+    css = g_strconcat("#" BALSA_MESSAGE_TEXT_HEADER " {font:", font, "}", NULL);
+
+    css_provider = gtk_css_provider_new();
+    gtk_css_provider_load_from_data(css_provider, css, -1, NULL);
+    g_free(css);
+
+    gtk_style_context_add_provider(gtk_widget_get_style_context(widget) ,
+                                   GTK_STYLE_PROVIDER(css_provider),
+                                   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    g_object_unref(css_provider);
 }
 
 /* quote_tag:
@@ -375,18 +382,11 @@ quote_tag(GtkTextBuffer * buffer, gint level, gint margin)
 
         if (!tag) {
             GdkRGBA *rgba;
-            GdkColor color;
 
             rgba = &balsa_app.quoted_color[q_level];
-            /* As of now, GtkTextTag has no "foreground-rgba" property :( */
-            color.red   = G_MAXUINT16 * rgba->red;
-            color.green = G_MAXUINT16 * rgba->green;
-            color.blue  = G_MAXUINT16 * rgba->blue;
-            color.pixel = 0;
-
             tag =
                 gtk_text_buffer_create_tag(buffer, name,
-                                           "foreground-gdk", &color,
+                                           "foreground-rgba", rgba,
 					   "left-margin", BALSA_LEFT_MARGIN
                                            + margin * level,
                                            NULL);
@@ -958,13 +958,30 @@ draw_cite_bar_real(cite_bar_t * bar, cite_bar_draw_mode_t * draw_mode)
 
     /* add a new widget if necessary */
     if (!bar->bar) {
+#define BALSA_MESSAGE_CITE_BAR "balsa-message-cite-bar"
+        gchar *color;
+        gchar *css;
+        GtkCssProvider *css_provider;
+
         bar->bar =
             balsa_cite_bar_new(height, bar->depth, draw_mode->dimension);
+        gtk_widget_set_name(bar->bar, BALSA_MESSAGE_CITE_BAR);
 
-        gtk_widget_override_color(bar->bar, GTK_STATE_FLAG_NORMAL,
-                                  &balsa_app.
-                                  quoted_color[(bar->depth -
-                                                1) % MAX_QUOTED_COLOR]);
+        color =
+            gdk_rgba_to_string(&balsa_app.
+                               quoted_color[(bar->depth -
+                                             1) % MAX_QUOTED_COLOR]);
+        css = g_strconcat("#" BALSA_MESSAGE_CITE_BAR " {color:", color, "}", NULL);
+        g_free(color);
+
+        css_provider = gtk_css_provider_new();
+        gtk_css_provider_load_from_data(css_provider, css, -1, NULL);
+        g_free(css);
+
+        gtk_style_context_add_provider(gtk_widget_get_style_context(bar->bar) ,
+                                       GTK_STYLE_PROVIDER(css_provider),
+                                       GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+        g_object_unref(css_provider);
 
         gtk_widget_show(bar->bar);
         gtk_text_view_add_child_in_window(draw_mode->view, bar->bar,
@@ -1045,19 +1062,17 @@ bmwt_populate_popup_menu(BalsaMessage * bm,
     GtkWidget *menuitem;
     gpointer mime_body = g_object_get_data(G_OBJECT(html), "mime-body");
 
-    menuitem = gtk_image_menu_item_new_from_stock(GTK_STOCK_ZOOM_IN, NULL);
+    menuitem = gtk_menu_item_new_with_label(_("Zoom In"));
     g_signal_connect_swapped(G_OBJECT(menuitem), "activate",
                              G_CALLBACK(bm_zoom_in), bm);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
 
-    menuitem =
-        gtk_image_menu_item_new_from_stock(GTK_STOCK_ZOOM_OUT, NULL);
+    menuitem = gtk_menu_item_new_with_label(_("Zoom Out"));
     g_signal_connect_swapped(G_OBJECT(menuitem), "activate",
                              G_CALLBACK(bm_zoom_out), bm);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
 
-    menuitem =
-        gtk_image_menu_item_new_from_stock(GTK_STOCK_ZOOM_100, NULL);
+    menuitem = gtk_menu_item_new_with_label(_("Zoom 100%"));
     g_signal_connect_swapped(G_OBJECT(menuitem), "activate",
                              G_CALLBACK(bm_zoom_reset), bm);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
@@ -1089,8 +1104,7 @@ bmwt_populate_popup_menu(BalsaMessage * bm,
     menuitem = gtk_separator_menu_item_new();
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
 
-    menuitem =
-        gtk_image_menu_item_new_from_stock(GTK_STOCK_PRINT, NULL);
+    menuitem = gtk_menu_item_new_with_label(_("Print..."));
     g_signal_connect_swapped(G_OBJECT(menuitem), "activate",
                              G_CALLBACK(libbalsa_html_print), html);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
@@ -1210,13 +1224,8 @@ bm_widget_new_vcard(BalsaMessage *bm, LibBalsaMessageBody *mime_body,
 
     mw->widget = gtk_grid_new();
     grid = (GtkGrid*)mw->widget;
-#if GTK_CHECK_VERSION(3, 2, 0)
     gtk_grid_set_row_spacing(grid, 6);
     gtk_grid_set_column_spacing(grid, 12);
-#else                           /* GTK_CHECK_VERSION(3, 2, 0) */
-    gtk_grid_set_row_spacing(grid, 12);
-    gtk_grid_set_column_spacing(grid, 6);
-#endif                          /* GTK_CHECK_VERSION(3, 2, 0) */
 
     w = gtk_button_new_with_mnemonic(_("S_tore Address"));
     gtk_grid_attach(grid, w, 0, 0, 2, 1);
@@ -1298,7 +1307,7 @@ fill_text_buf_cited(GtkWidget *widget, const gchar *text_body,
     regex_t rex;
 #endif                          /* USE_GREGEX */
     gboolean have_regex;
-    GdkColor color;
+    GdkRGBA *rgba;
 
     /* prepare citation regular expression for plain bodies */
     if (is_plain) {
@@ -1324,12 +1333,9 @@ fill_text_buf_cited(GtkWidget *widget, const gchar *text_body,
     screen = gtk_widget_get_screen(widget);
     margin = (char_width / 72.0) * gdk_screen_get_resolution(screen);
 
-    color.red   = G_MAXUINT16 * balsa_app.url_color.red;
-    color.green = G_MAXUINT16 * balsa_app.url_color.green;
-    color.blue  = G_MAXUINT16 * balsa_app.url_color.blue;
-    color.pixel = 0;
+    rgba = &balsa_app.url_color;
     gtk_text_buffer_create_tag(buffer, "url",
-                               "foreground-gdk", &color, NULL);
+                               "foreground-rgba", rgba, NULL);
     gtk_text_buffer_create_tag(buffer, "emphasize",
                                "foreground", "red",
                                "underline", PANGO_UNDERLINE_SINGLE,
