@@ -68,7 +68,8 @@ balsa_mime_widget_new_vcalendar(BalsaMessage * bm,
 			   libbalsa_vcal_method_to_str(vcal_obj->method));
     label = gtk_label_new(text);
     g_free(text);
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.0);
+    gtk_widget_set_halign(label, GTK_ALIGN_START);
+    gtk_widget_set_valign(label, GTK_ALIGN_START);
     gtk_container_add(GTK_CONTAINER(mw->widget), label);
 
     /* a reply may be created only for unread requests */
@@ -167,13 +168,8 @@ balsa_vevent_widget(LibBalsaVEvent * event, gboolean may_reply,
     LibBalsaIdentity *vevent_ident = NULL;
 
     grid = GTK_GRID(gtk_grid_new());
-#if GTK_CHECK_VERSION(3, 2, 0)
     gtk_grid_set_row_spacing(grid, 6);
     gtk_grid_set_column_spacing(grid, 12);
-#else                           /* GTK_CHECK_VERSION(3, 2, 0) */
-    gtk_grid_set_row_spacing(grid, 12);
-    gtk_grid_set_column_spacing(grid, 6);
-#endif                          /* GTK_CHECK_VERSION(3, 2, 0) */
     GRID_ATTACH(grid, event->summary, _("Summary:"));
     GRID_ATTACH_ADDRESS(grid, event->organizer, _("Organizer:"));
     GRID_ATTACH_DATE(grid, event->start, _("Start:"));
@@ -332,10 +328,14 @@ vevent_reply(GObject * button, GtkWidget * box)
     result = libbalsa_message_send(message, balsa_app.outbox, NULL,
 				   balsa_find_sentbox_by_url,
 				   ident->smtp_server,
+                                   GTK_WINDOW(gtk_widget_get_toplevel
+                                              ((GtkWidget *) button)),
 				   FALSE, balsa_app.debug, &error);
 #else
     result = libbalsa_message_send(message, balsa_app.outbox, NULL,
 				   balsa_find_sentbox_by_url,
+                                   GTK_WINDOW(gtk_widget_get_toplevel
+                                              ((GtkWidget *) button)),
 				   FALSE, balsa_app.debug, &error);
 #endif
     if (result != LIBBALSA_MESSAGE_CREATE_OK)
