@@ -895,7 +895,7 @@ condition_dialog_response(GtkWidget * dialog, gint response,
         break;
     case GTK_RESPONSE_HELP:     /* Help button */
         screen = gtk_widget_get_screen(dialog);
-        gtk_show_uri(screen, "ghelp:balsa?win-condition",
+        gtk_show_uri(screen, "help:balsa/win-filters#win-condition",
                      gtk_get_current_event_time(), &err);
 	if (err) {
 	    balsa_information_parented(GTK_WINDOW(dialog),
@@ -1236,10 +1236,11 @@ fe_edit_condition(GtkWidget * throwaway,gpointer is_new_cnd)
         condition_dialog=
             gtk_dialog_new_with_buttons("",
                                         GTK_WINDOW(fe_window),
-                                        GTK_DIALOG_DESTROY_WITH_PARENT,
-                                        GTK_STOCK_OK, GTK_RESPONSE_OK,
-                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                        GTK_STOCK_HELP, GTK_RESPONSE_HELP,
+                                        GTK_DIALOG_DESTROY_WITH_PARENT |
+                                        GTK_DIALOG_USE_HEADER_BAR,
+                                        _("_OK"), GTK_RESPONSE_OK,
+                                        _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                        _("_Help"), GTK_RESPONSE_HELP,
                                         NULL);
 #if HAVE_MACOSX_DESKTOP
 	libbalsa_macosx_menu_for_parent(condition_dialog, GTK_WINDOW(fe_window));
@@ -1494,7 +1495,7 @@ fe_dialog_response(GtkWidget * dialog, gint response, gpointer data)
 
     case GTK_RESPONSE_HELP:     /* Help button */
         screen = gtk_widget_get_screen(dialog);
-        gtk_show_uri(screen, "ghelp:balsa?win-filters",
+        gtk_show_uri(screen, "help:balsa/win-filters",
                      gtk_get_current_event_time(), &err);
 	if (err) {
 	    balsa_information_parented(GTK_WINDOW(dialog),
@@ -1698,7 +1699,7 @@ change_filter_name(gchar * old_name,gchar * new_name)
 void
 fe_new_pressed(GtkWidget * widget, gpointer data)
 {
-    const static char FLT_NAME_TEMPLATE[] = N_("New filter");
+    static const char FLT_NAME_TEMPLATE[] = N_("New filter");
     gint filter_number;
     LibBalsaFilter* fil;
     guint len = strlen(_(FLT_NAME_TEMPLATE))+4;
@@ -1897,26 +1898,16 @@ fe_apply_pressed(GtkWidget * widget, gpointer data)
     fil->action=action;
 
     if (fil->action == FILTER_COLOR) {
-#if GTK_CHECK_VERSION(3, 4, 0)
         GdkRGBA rgba;
-#else                           /* GTK_CHECK_VERSION(3, 4, 0) */
-        GdkColor color;
-#endif                          /* GTK_CHECK_VERSION(3, 4, 0) */
         GString *string = g_string_new(NULL);
         GtkToggleButton *toggle_button;
         gchar *color_string;
 
         toggle_button = (GTK_TOGGLE_BUTTON(fe_foreground_set));
         if (gtk_toggle_button_get_active(toggle_button)) {
-#if GTK_CHECK_VERSION(3, 4, 0)
             gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(fe_foreground),
                                        &rgba);
             color_string = gdk_rgba_to_string(&rgba);
-#else                           /* GTK_CHECK_VERSION(3, 4, 0) */
-            gtk_color_button_get_color(GTK_COLOR_BUTTON(fe_foreground),
-                                       &color);
-            color_string = gdk_color_to_string(&color);
-#endif                          /* GTK_CHECK_VERSION(3, 4, 0) */
             g_string_append_printf(string, "foreground:%s", color_string);
             g_free(color_string);
             gtk_toggle_button_set_active(toggle_button, FALSE);
@@ -1924,15 +1915,9 @@ fe_apply_pressed(GtkWidget * widget, gpointer data)
 
         toggle_button = (GTK_TOGGLE_BUTTON(fe_background_set));
         if (gtk_toggle_button_get_active(toggle_button)) {
-#if GTK_CHECK_VERSION(3, 4, 0)
             gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(fe_background),
                                        &rgba);
             color_string = gdk_rgba_to_string(&rgba);
-#else                           /* GTK_CHECK_VERSION(3, 4, 0) */
-            gtk_color_button_get_color(GTK_COLOR_BUTTON(fe_background),
-                                       &color);
-            color_string = gdk_color_to_string(&color);
-#endif                          /* GTK_CHECK_VERSION(3, 4, 0) */
             if (string->len > 0)
                 g_string_append_c(string, ';');
             g_string_append_printf(string, "background:%s", color_string);
@@ -2078,37 +2063,21 @@ fe_filters_list_selection_changed(GtkTreeSelection * selection,
     gtk_combo_box_set_active(GTK_COMBO_BOX(fe_op_codes_option_menu), pos);
     if (fil->action == FILTER_COLOR) {
         gchar **parts, **p;
-#if GTK_CHECK_VERSION(3, 4, 0)
         GdkRGBA rgba;
-#else                           /* GTK_CHECK_VERSION(3, 4, 0) */
-        GdkColor color;
-#endif                          /* GTK_CHECK_VERSION(3, 4, 0) */
 
         parts = g_strsplit(fil->action_string, ";", 2);
         for (p = parts; *p; p++) {
             if (g_str_has_prefix(*p, "foreground:")) {
-#if GTK_CHECK_VERSION(3, 4, 0)
                 gdk_rgba_parse(&rgba, (*p) + 11);
                 gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(fe_foreground),
                                            &rgba);
-#else                           /* GTK_CHECK_VERSION(3, 4, 0) */
-                gdk_color_parse((*p) + 11, &color);
-                gtk_color_button_set_color(GTK_COLOR_BUTTON(fe_foreground),
-                                           &color);
-#endif                          /* GTK_CHECK_VERSION(3, 4, 0) */
                 gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
                                              (fe_foreground_set), TRUE);
             }
             if (g_str_has_prefix(*p, "background:")) {
-#if GTK_CHECK_VERSION(3, 4, 0)
                 gdk_rgba_parse(&rgba, (*p) + 11);
                 gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(fe_background),
                                            &rgba);
-#else                           /* GTK_CHECK_VERSION(3, 4, 0) */
-                gdk_color_parse((*p) + 11, &color);
-                gtk_color_button_set_color(GTK_COLOR_BUTTON(fe_background),
-                                           &color);
-#endif                          /* GTK_CHECK_VERSION(3, 4, 0) */
                 gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
                                              (fe_background_set), TRUE);
             }
