@@ -223,17 +223,16 @@ build_left_side(void)
     gtk_box_pack_start(GTK_BOX(vbox), bbox, FALSE, FALSE, 2);
 
     /* new button */
-    fe_new_button = balsa_stock_button_with_label(GTK_STOCK_NEW, _("_New"));
+    fe_new_button = gtk_button_new_with_mnemonic(_("_New"));
     g_signal_connect(G_OBJECT(fe_new_button), "clicked",
 		     G_CALLBACK(fe_new_pressed), NULL);
     gtk_container_add(GTK_CONTAINER(bbox), fe_new_button);
     /* delete button */
-    fe_delete_button =
-        balsa_stock_button_with_label(GTK_STOCK_DELETE, _("_Delete"));
+    fe_delete_button = gtk_button_new_with_mnemonic(("_Delete"));
     g_signal_connect(G_OBJECT(fe_delete_button), "clicked",
 		     G_CALLBACK(fe_delete_pressed), NULL);
     gtk_container_add(GTK_CONTAINER(bbox), fe_delete_button);
-    gtk_widget_set_sensitive(fe_delete_button,FALSE);
+    gtk_widget_set_sensitive(fe_delete_button, FALSE);
 
     return vbox;
 }				/* end build_left_side() */
@@ -339,11 +338,7 @@ fe_make_color_buttons(void)
 {
     GtkWidget *grid_widget;
     GtkGrid *grid;
-#if GTK_CHECK_VERSION(3, 4, 0)
     GdkRGBA rgba;
-#else                           /* GTK_CHECK_VERSION(3, 4, 0) */
-    GdkColor color;
-#endif                          /* GTK_CHECK_VERSION(3, 4, 0) */
 
     grid_widget = gtk_grid_new();
     grid = GTK_GRID(grid_widget);
@@ -352,13 +347,8 @@ fe_make_color_buttons(void)
 
     fe_foreground_set = gtk_check_button_new_with_mnemonic(_("Foreground"));
     gtk_grid_attach(grid, fe_foreground_set, 0, 0, 1, 1);
-#if GTK_CHECK_VERSION(3, 4, 0)
     gdk_rgba_parse(&rgba, "black");
     fe_foreground = gtk_color_button_new_with_rgba(&rgba);
-#else                           /* GTK_CHECK_VERSION(3, 4, 0) */
-    gdk_color_parse("black", &color);
-    fe_foreground = gtk_color_button_new_with_color(&color);
-#endif                          /* GTK_CHECK_VERSION(3, 4, 0) */
     gtk_widget_set_sensitive(fe_foreground, FALSE);
     gtk_grid_attach(grid, fe_foreground, 1, 0, 1, 1);
     g_signal_connect(fe_foreground_set, "toggled",
@@ -368,13 +358,8 @@ fe_make_color_buttons(void)
 
     fe_background_set = gtk_check_button_new_with_mnemonic(_("Background"));
     gtk_grid_attach(grid, fe_background_set, 0, 1, 1, 1);
-#if GTK_CHECK_VERSION(3, 4, 0)
     gdk_rgba_parse(&rgba, "white");
     fe_background = gtk_color_button_new_with_rgba(&rgba);
-#else                           /* GTK_CHECK_VERSION(3, 4, 0) */
-    gdk_color_parse("white", &color);
-    fe_background = gtk_color_button_new_with_color(&color);
-#endif                          /* GTK_CHECK_VERSION(3, 4, 0) */
     gtk_widget_set_sensitive(fe_background, FALSE);
     gtk_grid_attach(grid, fe_background, 1, 1, 1, 1);
     g_signal_connect(fe_background_set, "toggled",
@@ -416,14 +401,11 @@ build_action_page(GtkWindow * window)
     dialog =
         gtk_file_chooser_dialog_new(_("Use Sound..."), NULL,
                                     GTK_FILE_CHOOSER_ACTION_OPEN,
-                                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                    GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                                    _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                    _("_Open"),   GTK_RESPONSE_ACCEPT,
                                     NULL);
     gtk_dialog_set_default_response(GTK_DIALOG(dialog),
                                     GTK_RESPONSE_ACCEPT);
-    gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
-                                            GTK_RESPONSE_ACCEPT,
-                                            GTK_RESPONSE_CANCEL, -1);
     fe_sound_entry = gtk_file_chooser_button_new_with_dialog(dialog);
     gtk_widget_set_hexpand(fe_sound_entry, TRUE);
     gtk_grid_attach(GTK_GRID(grid), fe_sound_entry, 1, 0, 1, 1);
@@ -515,18 +497,17 @@ build_right_side(GtkWindow * window)
     bbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
     gtk_box_pack_start(GTK_BOX(rightside), bbox, FALSE, FALSE, 0);
 
-    fe_apply_button = gtk_button_new_from_stock(GTK_STOCK_APPLY);
+    fe_apply_button = gtk_button_new_with_mnemonic(_("_Apply"));
     g_signal_connect(G_OBJECT(fe_apply_button), "clicked",
 		     G_CALLBACK(fe_apply_pressed), NULL);
     gtk_container_add(GTK_CONTAINER(bbox), fe_apply_button);
 
-    fe_revert_button =
-        balsa_stock_button_with_label(GTK_STOCK_UNDO, _("Revert"));
+    fe_revert_button = gtk_button_new_with_mnemonic(_("Re_vert"));
     g_signal_connect(G_OBJECT(fe_revert_button), "clicked",
 		     G_CALLBACK(fe_revert_pressed), NULL);
     gtk_container_add(GTK_CONTAINER(bbox), fe_revert_button);
-    gtk_widget_set_sensitive(fe_apply_button,FALSE);
-    gtk_widget_set_sensitive(fe_revert_button,FALSE);
+    gtk_widget_set_sensitive(fe_apply_button, FALSE);
+    gtk_widget_set_sensitive(fe_revert_button, FALSE);
 
     return rightside;
 }				/* end build_right_side() */
@@ -561,7 +542,7 @@ fe_collect_user_headers(LibBalsaCondition * condition)
  */
 #define BALSA_FILTER_PADDING 6
 void
-filters_edit_dialog(void)
+filters_edit_dialog(GtkWindow * parent)
 {
     GtkWidget *hbox;
     GtkWidget *piece;
@@ -585,14 +566,12 @@ filters_edit_dialog(void)
 
     piece = build_left_side();
 
-    fe_window = gtk_dialog_new_with_buttons(_("Balsa Filters"),
-                                            NULL, 0, /* FIXME */
-                                            GTK_STOCK_OK,
-                                            GTK_RESPONSE_OK,
-                                            GTK_STOCK_CANCEL,
-                                            GTK_RESPONSE_CANCEL,
-                                            GTK_STOCK_HELP,
-                                            GTK_RESPONSE_HELP,
+    fe_window = gtk_dialog_new_with_buttons(_("Filters"),
+                                            parent,
+                                            GTK_DIALOG_USE_HEADER_BAR,
+                                            _("_OK"), GTK_RESPONSE_OK,
+                                            _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                            _("_Help"), GTK_RESPONSE_HELP,
 					    NULL);
 
     g_signal_connect(G_OBJECT(fe_window), "response",
