@@ -51,7 +51,7 @@ GtkWidget * fex_window;
  * Returns immediately, but fires off the filter export dialog.
  */
 void
-filters_export_dialog(void)
+filters_export_dialog(GtkWindow * parent)
 {
     GtkTreeView *list;
     GtkTreeModel *model;
@@ -74,11 +74,12 @@ filters_export_dialog(void)
     fex_already_open = TRUE;
 
     fex_window =
-        gtk_dialog_new_with_buttons(_("Balsa Filters Export"),
-                                    NULL, 0, /* FIXME */
-                                    GTK_STOCK_OK,     GTK_RESPONSE_OK,
-                                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                    GTK_STOCK_HELP,   GTK_RESPONSE_HELP,
+        gtk_dialog_new_with_buttons(_("Export Filters"),
+                                    parent,
+                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    _("_OK"), GTK_RESPONSE_OK,
+                                    _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                    _("_Help"), GTK_RESPONSE_HELP,
                                     NULL);
     gtk_window_set_wmclass(GTK_WINDOW(fex_window), "filter-export",
                            "Balsa");
