@@ -105,7 +105,7 @@ folder_conf_response(GtkDialog * dialog, int response,
     switch (response) {
     case GTK_RESPONSE_HELP:
         screen = gtk_widget_get_screen(GTK_WIDGET(dialog));
-        gtk_show_uri(screen, "ghelp:balsa?folder-config",
+        gtk_show_uri(screen, "help:balsa/folder-config",
                      gtk_get_current_event_time(), &err);
         if (err) {
             balsa_information(LIBBALSA_INFORMATION_WARNING,
@@ -302,10 +302,12 @@ folder_conf_imap_node(BalsaMailboxNode *mn)
         GTK_DIALOG(gtk_dialog_new_with_buttons
                    (_("Remote IMAP folder"),
                     GTK_WINDOW(balsa_app.main_window),
-                    GTK_DIALOG_DESTROY_WITH_PARENT,
+                    GTK_DIALOG_DESTROY_WITH_PARENT |
+                    GTK_DIALOG_USE_HEADER_BAR,
                     mn ? _("_Update") : _("C_reate"), GTK_RESPONSE_OK,
-                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                    GTK_STOCK_HELP, GTK_RESPONSE_HELP, NULL));
+                    _("_Cancel"), GTK_RESPONSE_CANCEL,
+                    _("_Help"), GTK_RESPONSE_HELP,
+                    NULL));
 #if HAVE_MACOSX_DESKTOP
     libbalsa_macosx_menu_for_parent(GTK_WIDGET(fcw->dialog), GTK_WINDOW(balsa_app.main_window));
 #endif
@@ -566,9 +568,10 @@ browse_button_cb(GtkWidget * widget, SubfolderDialogData * sdd)
     dialog =
         gtk_dialog_new_with_buttons(_("Select parent folder"),
                                     GTK_WINDOW(sdd->dialog),
-                                    GTK_DIALOG_DESTROY_WITH_PARENT,
-                                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                    GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                    GTK_DIALOG_DESTROY_WITH_PARENT |
+                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                    _("_Help"), GTK_RESPONSE_HELP,
                                     NULL);
 #if HAVE_MACOSX_DESKTOP
     libbalsa_macosx_menu_for_parent(dialog, GTK_WINDOW(sdd->dialog));
@@ -648,16 +651,16 @@ subfolder_conf_clicked_ok(SubfolderDialogData * sdd)
                                      "INBOX and its subfolders will remain.\n"
                                      "What would you like to do?"),
 folder, parent);
-                GtkWidget *ask = gtk_dialog_new_with_buttons(_("Question"),
-                                                             GTK_WINDOW
-                                                             (sdd->dialog),
-                                                             GTK_DIALOG_MODAL,
-                                                             _
-                                                             ("Rename INBOX"),
-                                                             GTK_RESPONSE_OK,
-                                                             _("Cancel"),
-                                                             GTK_RESPONSE_CANCEL,
-                                                             NULL);
+                GtkWidget *ask =
+                    gtk_dialog_new_with_buttons(_("Question"),
+                                                GTK_WINDOW(sdd->dialog),
+                                                GTK_DIALOG_MODAL |
+                                                GTK_DIALOG_USE_HEADER_BAR,
+                                                _("Rename INBOX"),
+                                                GTK_RESPONSE_OK,
+                                                _("Cancel"),
+                                                GTK_RESPONSE_CANCEL,
+                                                NULL);
 #if HAVE_MACOSX_DESKTOP
 		libbalsa_macosx_menu_for_parent(ask, GTK_WINDOW(sdd->dialog));
 #endif
@@ -797,10 +800,11 @@ folder_conf_imap_sub_node(BalsaMailboxNode * mn)
         GTK_DIALOG(gtk_dialog_new_with_buttons
                    (_("Remote IMAP subfolder"), 
                     GTK_WINDOW(balsa_app.main_window),
-                    GTK_DIALOG_DESTROY_WITH_PARENT, /* must NOT be modal */
+                    GTK_DIALOG_DESTROY_WITH_PARENT | /* must NOT be modal */
+                    GTK_DIALOG_USE_HEADER_BAR,
                     mn ? _("_Update") : _("_Create"), GTK_RESPONSE_OK,
-                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                    GTK_STOCK_HELP,   GTK_RESPONSE_HELP,
+                    _("_Cancel"), GTK_RESPONSE_CANCEL,
+                    _("_Help"), GTK_RESPONSE_HELP,
                     NULL));
 #if HAVE_MACOSX_DESKTOP
     libbalsa_macosx_menu_for_parent(GTK_WIDGET(sdd->dialog), GTK_WINDOW(balsa_app.main_window));
@@ -823,13 +827,8 @@ folder_conf_imap_sub_node(BalsaMailboxNode * mn)
     }
 
     grid = libbalsa_create_grid();
-#if GTK_CHECK_VERSION(3, 2, 0)
     gtk_grid_set_row_spacing(GTK_GRID(grid), 6);
     gtk_grid_set_column_spacing(GTK_GRID(grid), 12);
-#else                           /* GTK_CHECK_VERSION(3, 2, 0) */
-    gtk_grid_set_row_spacing(GTK_GRID(grid), 12);
-    gtk_grid_set_column_spacing(GTK_GRID(grid), 6);
-#endif                          /* GTK_CHECK_VERSION(3, 2, 0) */
     gtk_container_set_border_width(GTK_CONTAINER(grid), 12);
     if (mn)
         content = grid;
