@@ -232,16 +232,17 @@ balsa_information_list(GtkWindow *parent, LibBalsaInformationType type,
 	information_dialog =
 	    gtk_dialog_new_with_buttons(_("Information - Balsa"), 
                                         parent,
-                                        GTK_DIALOG_DESTROY_WITH_PARENT,
-                                        GTK_STOCK_CLEAR, GTK_RESPONSE_APPLY,
-                                        GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                                        GTK_DIALOG_DESTROY_WITH_PARENT |
+                                        GTK_DIALOG_USE_HEADER_BAR,
+                                        _("_Clear"), GTK_RESPONSE_APPLY,
+                                        _("Cl_ose"), GTK_RESPONSE_CANCEL,
                                         NULL);
 #if HAVE_MACOSX_DESKTOP
 	libbalsa_macosx_menu_for_parent(information_dialog, parent);
 #endif
 	/* Default is to close */
 	gtk_dialog_set_default_response(GTK_DIALOG(information_dialog), 
-                                        GTK_RESPONSE_CLOSE);
+                                        GTK_RESPONSE_CANCEL);
 
 	/* Reset the policy gtk_dialog_new makes itself non-resizable */
 	gtk_window_set_resizable(GTK_WINDOW(information_dialog), TRUE);
