@@ -416,7 +416,7 @@ mailbox_conf_delete(BalsaMailboxNode * mbnode)
         gtk_dialog_add_buttons(GTK_DIALOG(ask),
                                _("Remove from _list"), 0,
                                _("Remove from list and _disk"), 1,
-                               GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                               _("_Cancel"), GTK_RESPONSE_CANCEL,
                                NULL);
     } else if (LIBBALSA_IS_MAILBOX_IMAP(mailbox) && !mailbox->config_prefix) {
 	/* deleting remote IMAP mailbox in a folder set */
@@ -437,7 +437,7 @@ mailbox_conf_delete(BalsaMailboxNode * mbnode)
 			             mailbox->name, mailbox->name);
         gtk_dialog_add_buttons(GTK_DIALOG(ask),
                                _("_Remove from server"), 0,
-                               GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                               _("_Cancel"), GTK_RESPONSE_CANCEL,
                                NULL);
     } else { /* deleting other remote mailbox */
         ask = gtk_message_dialog_new(GTK_WINDOW(balsa_app.main_window), 0,
@@ -453,7 +453,7 @@ mailbox_conf_delete(BalsaMailboxNode * mbnode)
 			             mailbox->name);
         gtk_dialog_add_buttons(GTK_DIALOG(ask),
                                _("_Remove from list"), 0,
-                               GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                               _("_Cancel"), GTK_RESPONSE_CANCEL,
                                NULL);
     }
     
@@ -1136,7 +1136,7 @@ create_local_mailbox_dialog(MailboxConfWindow *mcw)
                                     GTK_WINDOW(balsa_app.main_window),
                                     action,
                                     mcw->ok_button_name, MCW_RESPONSE,
-                                    GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                                    _("_Cancel"), GTK_RESPONSE_CANCEL,
                                     NULL);
     g_free(title);
 #if HAVE_MACOSX_DESKTOP
@@ -1170,9 +1170,10 @@ create_generic_dialog(MailboxConfWindow * mcw)
     GtkWidget *dialog =
         gtk_dialog_new_with_buttons(_("Remote Mailbox Configurator"),
                                     GTK_WINDOW(balsa_app.main_window),
-                                    GTK_DIALOG_DESTROY_WITH_PARENT,
+                                    GTK_DIALOG_DESTROY_WITH_PARENT |
+                                    GTK_DIALOG_USE_HEADER_BAR,
                                     mcw->ok_button_name, MCW_RESPONSE,
-                                    GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                                    _("_Close"), GTK_RESPONSE_CLOSE,
                                     NULL);
 #if HAVE_MACOSX_DESKTOP
     libbalsa_macosx_menu_for_parent(dialog, GTK_WINDOW(balsa_app.main_window));
@@ -1396,13 +1397,6 @@ create_imap_mailbox_dialog(MailboxConfWindow *mcw)
  * Other aspects like sort column and sort order are just remembered
  * when the user changes them with the GtkTreeView controls. */
 
-/* Free a BalsaMailboxConfView. */
-static void
-mailbox_conf_view_free(BalsaMailboxConfView *view_info)
-{
-    g_free(view_info);
-}
-
 /* Create the dialog items in the dialog's grid, and allocate and
  * populate a BalsaMailboxConfView with the info that needs to be passed
  * around. The memory is deallocated when the window is finalized. 
@@ -1430,8 +1424,7 @@ mailbox_conf_view_new_full(LibBalsaMailbox * mailbox,
     gint active;
 
     view_info = g_new(BalsaMailboxConfView, 1);
-    g_object_weak_ref(G_OBJECT(window),
-                      (GWeakNotify) mailbox_conf_view_free, view_info);
+    g_object_weak_ref(G_OBJECT(window), (GWeakNotify) g_free, view_info);
     view_info->window = window;
 
     label = libbalsa_create_grid_label(_("_Identity:"), grid, row);
