@@ -28,11 +28,7 @@
 #include <libnotify/notify.h>
 #endif
 
-#if GLIB_CHECK_VERSION(2, 32, 0)
 #include <gio/gio.h>
-#elif defined(HAVE_LIBNM_GLIB)
-#include <nm-client.h>
-#endif
 
 #include "mailbox-node.h"
 #include "toolbar-factory.h"
@@ -62,7 +58,7 @@ typedef enum {
 
 
 struct _BalsaWindow {
-    GtkWindow window;
+    GtkApplicationWindow window;
 
     GtkWidget *toolbar;
     GtkWidget *sos_bar;
@@ -82,37 +78,23 @@ struct _BalsaWindow {
 
     guint set_message_id;
 
-    GtkActionGroup *action_group;
-    GtkActionGroup *mailbox_action_group;
-    GtkActionGroup *message_action_group;
-    GtkActionGroup *current_message_action_group;
-    GtkActionGroup *modify_message_action_group;
-
     /* Progress bar stuff: */
     BalsaWindowProgress progress_type;
     guint activity_handler;
     guint activity_counter;
     GSList *activity_messages;
 
-    /* New mail notification: */
-    GtkStatusIcon *new_mail_tray;
 #ifdef HAVE_NOTIFY
     NotifyNotification *new_mail_note;
 #endif                         /* HAVE_NOTIFY */
 
-#if GLIB_CHECK_VERSION(2, 32, 0)
     /* Support GNetworkMonitor: */
     gboolean network_available;
     time_t last_check_time;
-#elif defined(HAVE_LIBNM_GLIB)
-    /* NetworkManager state */
-    NMState nm_state;
-    time_t last_check_time;
-#endif                          /* defined(HAVE_LIBNM_GLIB) */
 };
 
 struct _BalsaWindowClass {
-    GtkWindowClass parent_class;
+    GtkApplicationWindowClass parent_class;
 
     void (*open_mbnode)  (BalsaWindow * window,
                           BalsaMailboxNode * mbnode,
@@ -156,13 +138,12 @@ gboolean mail_progress_notify_cb(GIOChannel * source,
 gboolean send_progress_notify_cb(GIOChannel * source,
                                  GIOCondition condition,
                                  BalsaWindow ** window);
-void check_new_messages_cb(GtkAction * action, gpointer data);
 void check_new_messages_real(BalsaWindow * window, int type);
 void check_new_messages_count(LibBalsaMailbox * mailbox, gboolean notify);
 void empty_trash(BalsaWindow * window);
 void update_view_menu(BalsaWindow * window);
 BalsaToolbarModel *balsa_window_get_toolbar_model(void);
-GtkUIManager *balsa_window_ui_manager_new(BalsaWindow * window);
+void balsa_window_add_action_entries(GActionMap * action_map);
 void balsa_window_select_all(GtkWindow * window);
 gboolean balsa_window_next_unread(BalsaWindow * window);
 
