@@ -255,10 +255,6 @@ pthread_mutex_t checking_mail_lock = PTHREAD_MUTEX_INITIALIZER;
 static void
 threads_init(void)
 {
-#if !GLIB_CHECK_VERSION(2, 35, 0)
-    g_type_init();
-#endif                          /* !GLIB_CHECK_VERSION(2, 35, 0) */
-
     pthread_mutex_init(&send_messages_lock, NULL);
     if (pipe(mail_thread_pipes) < 0) {
 	g_log("BALSA Init", G_LOG_LEVEL_DEBUG,
@@ -838,8 +834,9 @@ handle_remote(int argc, char **argv,
 }
 
 static int
-command_line_cb(GApplication * application,
-                GApplicationCommandLine * command_line)
+command_line_cb(GApplication            * application,
+                GApplicationCommandLine * command_line,
+                gpointer                  user_data)
 {
     gchar **args, **argv;
     gint argc;
@@ -871,15 +868,17 @@ command_line_cb(GApplication * application,
 int
 main(int argc, char **argv)
 {
-    GApplication *application;
+    GtkApplication *application;
     int status;
 
-    application = g_application_new("org.desktop.Balsa",
-                                    G_APPLICATION_HANDLES_COMMAND_LINE);
+    balsa_app.application = application =
+        gtk_application_new("org.desktop.Balsa",
+                            G_APPLICATION_HANDLES_COMMAND_LINE);
     g_signal_connect(application, "command-line",
                      G_CALLBACK(command_line_cb), NULL);
+    g_object_set(application, "register-session", TRUE, NULL);
 
-    status = g_application_run(application, argc, argv);
+    status = g_application_run(G_APPLICATION(application), argc, argv);
 
     g_object_unref(application);
 
