@@ -752,6 +752,8 @@ config_global_load(void)
     load_color("UrlColor", DEFAULT_URL_COLOR, &balsa_app.url_color);
 
     /* ... font used to display messages */
+    balsa_app.use_system_fonts =
+        libbalsa_conf_get_bool("UseSystemFonts=true");
     g_free(balsa_app.message_font);
     balsa_app.message_font =
 	libbalsa_conf_get_string("MessageFont=" DEFAULT_MESSAGE_FONT);
@@ -1273,6 +1275,7 @@ config_save(void)
 			 libbalsa_mailbox_get_threading_type(NULL));
     libbalsa_conf_set_bool("MarkQuoted", balsa_app.mark_quoted);
     libbalsa_conf_set_string("QuoteRegex", balsa_app.quote_regex);
+    libbalsa_conf_set_bool("UseSystemFonts", balsa_app.use_system_fonts);
     libbalsa_conf_set_string("MessageFont", balsa_app.message_font);
     libbalsa_conf_set_string("SubjectFont", balsa_app.subject_font);
     libbalsa_conf_set_bool("WordWrap", balsa_app.browse_wrap);
@@ -1771,15 +1774,6 @@ config_load_mailbox_view(const gchar * url)
 
     view = libbalsa_mailbox_view_new();
 
-    if (libbalsa_conf_has_key("MailingListAddress")) {
-        gchar *address;
-
-        address = libbalsa_conf_get_string("MailingListAddress");
-        view->mailing_list_address =
-            internet_address_list_parse_string(address);
-        g_free(address);
-    }
-
     view->identity_name = libbalsa_conf_get_string("Identity");
 
     if (libbalsa_conf_has_key("Threading"))
@@ -1843,14 +1837,6 @@ config_save_mailbox_view(const gchar * url, LibBalsaMailboxView * view)
     libbalsa_conf_push_group(prefix);
     g_free(prefix);
 
-    if (view->mailing_list_address !=
-	libbalsa_mailbox_get_mailing_list_address(NULL)) {
-       gchar* tmp =
-	   internet_address_list_to_string(view->mailing_list_address,
-		                           FALSE);
-       libbalsa_conf_set_string("MailingListAddress", tmp);
-       g_free(tmp);
-    }
     if (view->identity_name  != libbalsa_mailbox_get_identity_name(NULL))
 	libbalsa_conf_set_string("Identity", view->identity_name);
     if (view->threading_type != libbalsa_mailbox_get_threading_type(NULL))
