@@ -65,7 +65,7 @@ extern "C" {
 #if !defined(ENABLE_TOUCH_UI)
 	GtkWidget *replyto[2];
 #endif                          /* ENABLE_TOUCH_UI */
-	GtkWidget *attachments[4];
+	GtkWidget *tree_view;
         gchar *in_reply_to;
         GList *references;
 	GtkWidget *text;
@@ -78,7 +78,7 @@ extern "C" {
 	SendType type;
         gboolean is_continue;
 	/* language selection related data */
-	const gchar *spell_check_lang;
+	gchar *spell_check_lang;
 	GtkWidget *current_language_menu;
 	/* identity related data */
 	LibBalsaIdentity* ident;
@@ -98,7 +98,8 @@ extern "C" {
         gulong identities_changed_id;
 	gboolean flow;          /* send format=flowed */ 
 	gboolean send_mp_alt;   /* send multipart/alternative (plain and html) */ 
-	gboolean req_dispnotify; /* send a MDN */ 
+	gboolean req_mdn; 	 /* send a MDN */
+	gboolean req_dsn;	 /* send a delivery status notification */
 	gboolean quit_on_close; /* quit balsa after the compose window */
 	                        /* is closed.                          */
 #ifdef HAVE_GPGME
@@ -112,11 +113,9 @@ extern "C" {
         /* To update cursor after text is inserted. */
         GtkTextMark *insert_mark;
 
-        GtkActionGroup *action_group;
-	GtkActionGroup *ready_action_group;
-#if !defined(ENABLE_TOUCH_UI)
-        GtkActionGroup *gpg_action_group;
-#endif                          /* ENABLE_TOUCH_UI */
+        GtkWidget *paned;
+        GtkSizeGroup *size_group;
+        gboolean ready_to_send;
     };
 
     BalsaSendmsg *sendmsg_window_compose(void);
@@ -148,7 +147,7 @@ extern "C" {
                                                GArray * selected,
                                                SendType type);
     BalsaToolbarModel *sendmsg_window_get_toolbar_model(void);
-    GtkUIManager *sendmsg_window_ui_manager_new(BalsaSendmsg * bsmsg);
+    void sendmsg_window_add_action_entries(GActionMap * action_map);
 
 #define SENDMSG_WINDOW_QUIT_ON_CLOSE(bsmsg) ((bsmsg)->quit_on_close=TRUE)
 
