@@ -40,9 +40,15 @@
 #include "quote-color.h"
 #include "balsa-icons.h"
 
+#if HAVE_GTKSOURCEVIEW
+#include <gtksourceview/gtksourcebuffer.h>
+#endif                          /* HAVE_GTKSOURCEVIEW */
+
+#define BALSA_SPELL_CHECK_PADDING 6
+
 /* the basic structures */
 struct _BalsaSpellCheck {
-    GtkDialog dialog;
+    GtkWindow window;
 
     GtkTextView *text_view;
     GtkTreeView *tree_view;
@@ -54,7 +60,11 @@ struct _BalsaSpellCheck {
     gchar **suggestions;
 
     /* restoration information */
+#if HAVE_GTKSOURCEVIEW
+    GtkSourceBuffer *original_text;
+#else                           /* HAVE_GTKSOURCEVIEW */
     GtkTextBuffer *original_text;
+#endif                          /* HAVE_GTKSOURCEVIEW */
     GtkTextMark *original_mark;
     gint original_offset;
 
@@ -72,9 +82,7 @@ struct _BalsaSpellCheck {
 };
 
 struct _BalsaSpellCheckClass {
-    GtkDialogClass parent_class;
-
-    void (*done_spell_check) (BalsaSpellCheck * spell_check);
+    GtkWindowClass parent_class;
 };
 
 /* enumerations */
@@ -138,7 +146,7 @@ static void spch_finish(BalsaSpellCheck * spell_check,
 
 /* define the class */
 
-G_DEFINE_TYPE(BalsaSpellCheck, balsa_spell_check, GTK_TYPE_DIALOG);
+G_DEFINE_TYPE(BalsaSpellCheck, balsa_spell_check, GTK_TYPE_WINDOW);
 
 static void
 balsa_spell_check_class_init(BalsaSpellCheckClass * klass)
@@ -158,8 +166,6 @@ balsa_spell_check_class_init(BalsaSpellCheckClass * klass)
                                                         G_PARAM_READWRITE));
 
     object_class->dispose = balsa_spell_check_destroy;
-
-    klass->done_spell_check = NULL;
 }
 
 
@@ -199,7 +205,7 @@ spch_get_property(GObject * object, guint prop_id, GValue * value,
 
 
 /* balsa_spell_check_new ()
- * 
+ *
  * Create a new spell check widget.
  * */
 GtkWidget *
@@ -209,19 +215,24 @@ balsa_spell_check_new(GtkWindow * parent)
 
     g_return_val_if_fail(GTK_IS_WINDOW(parent), NULL);
 
-    spell_check = g_object_new(BALSA_TYPE_SPELL_CHECK, NULL);
-    gtk_window_set_transient_for(GTK_WINDOW(spell_check), parent);
+    spell_check = g_object_new(BALSA_TYPE_SPELL_CHECK,
+                               "type", GTK_WINDOW_TOPLEVEL,
+                               "transient-for", parent,
+                               "destroy-with-parent", TRUE,
+                               "title", _("Spell check"),
+                               "border-width", BALSA_SPELL_CHECK_PADDING,
+                               NULL);
 
-    return GTK_WIDGET(spell_check);
+    return (GtkWidget *) spell_check;
 }
 
 
 /* balsa_spell_check_new_with_text
- * 
+ *
  * Create a new spell check widget, assigning the GtkText to check.
  * */
 GtkWidget *
-balsa_spell_check_new_with_text(GtkWindow * parent, 
+balsa_spell_check_new_with_text(GtkWindow   * parent,
                                 GtkTextView * check_text)
 {
     BalsaSpellCheck *spell_check;
@@ -229,20 +240,20 @@ balsa_spell_check_new_with_text(GtkWindow * parent,
     g_return_val_if_fail(GTK_IS_WINDOW(parent), NULL);
     g_return_val_if_fail(GTK_IS_TEXT_VIEW(check_text), NULL);
 
-    spell_check = BALSA_SPELL_CHECK(balsa_spell_check_new(parent));
+    spell_check = (BalsaSpellCheck *) balsa_spell_check_new(parent);
     spell_check->text_view = check_text;
 
-    return GTK_WIDGET(spell_check);
+    return (GtkWidget *) spell_check;
 }
 
 
 /* balsa_spell_check_set_text ()
- * 
+ *
  * Set the text widget the spell check should check.
  * */
 void
 balsa_spell_check_set_text(BalsaSpellCheck * spell_check,
-			   GtkTextView * check_text)
+                           GtkTextView     * check_text)
 {
     g_return_if_fail(BALSA_IS_SPELL_CHECK(spell_check));
     g_return_if_fail(GTK_IS_TEXT_VIEW(check_text));
@@ -252,12 +263,12 @@ balsa_spell_check_set_text(BalsaSpellCheck * spell_check,
 
 
 /* balsa_spell_check_set_language ()
- * 
+ *
  * Set the language to do spell checking in.
  * */
 void
 balsa_spell_check_set_language(BalsaSpellCheck * spell_check,
-			       const gchar * language)
+                               const gchar     * language)
 {
     g_return_if_fail(BALSA_IS_SPELL_CHECK(spell_check));
 
@@ -282,10 +293,9 @@ balsa_spell_check_init(BalsaSpellCheck * spell_check)
     GtkCellRenderer *renderer;
     GtkTreeViewColumn *column;
     GtkTreeSelection *selection;
+    GtkWidget *box_widget;
     GtkBox *box;
 
-    const guint padding = 6;
-
     /* Set spell checker */
 
     spell_check->original_text = NULL;
@@ -296,7 +306,11 @@ balsa_spell_check_init(BalsaSpellCheck * spell_check)
     /* setup suggestion display */
     widget = gtk_entry_new();
     spell_check->entry = GTK_ENTRY(widget);
-    box = GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(spell_check)));
+    box_widget =
+        gtk_box_new(GTK_ORIENTATION_VERTICAL, BALSA_SPELL_CHECK_PADDING);
+    gtk_container_add((GtkContainer *) spell_check, box_widget);
+
+    box = (GtkBox *) box_widget;
     gtk_box_pack_start(box, widget, FALSE, FALSE, 0);
 
     sw = gtk_scrolled_window_new(NULL, NULL);
@@ -326,15 +340,14 @@ balsa_spell_check_init(BalsaSpellCheck * spell_check)
     gtk_tree_view_set_headers_visible(tree_view, FALSE);
 
     /* setup buttons to perform actions */
-    box = GTK_BOX(gtk_dialog_get_action_area(GTK_DIALOG(spell_check)));
     widget = gtk_grid_new();
     gtk_box_pack_start(box, widget, FALSE, FALSE, 0);
 
     grid = GTK_GRID(widget);
-    gtk_grid_set_row_spacing(grid, padding);
-    gtk_grid_set_column_spacing(grid, padding);
+    gtk_grid_set_row_spacing(grid, BALSA_SPELL_CHECK_PADDING);
+    gtk_grid_set_column_spacing(grid, BALSA_SPELL_CHECK_PADDING);
 
-    widget = balsa_stock_button_with_label(GTK_STOCK_REDO, _("C_hange"));
+    widget = gtk_button_new_with_mnemonic(_("C_hange"));
     gtk_widget_set_tooltip_text(widget,
                                 _("Replace the current word "
                                   "with the selected suggestion"));
@@ -342,8 +355,7 @@ balsa_spell_check_init(BalsaSpellCheck * spell_check)
 		     G_CALLBACK(change_cb), spell_check);
     gtk_grid_attach(grid, widget, 0, 0, 1, 1);
 
-    widget = balsa_stock_button_with_label(GTK_STOCK_REFRESH,
-                                           _("Change _All"));
+    widget = gtk_button_new_with_mnemonic(_("Change _All"));
     gtk_widget_set_tooltip_text(widget,
                                 _("Replace all occurrences of the current word "
                                   "with the selected suggestion"));
@@ -351,44 +363,39 @@ balsa_spell_check_init(BalsaSpellCheck * spell_check)
 		     G_CALLBACK(change_all_cb), spell_check);
     gtk_grid_attach(grid, widget, 0, 1, 1, 1);
 
-    widget = balsa_stock_button_with_label(GTK_STOCK_GO_FORWARD,
-                                           _("_Ignore"));
+    widget = gtk_button_new_with_mnemonic(_("_Ignore"));
     gtk_widget_set_tooltip_text(widget,
                                 _("Skip the current word"));
     g_signal_connect(widget, "clicked",
 		     G_CALLBACK(ignore_cb), spell_check);
     gtk_grid_attach(grid, widget, 1, 0, 1, 1);
 
-    widget = balsa_stock_button_with_label(GTK_STOCK_GOTO_LAST,
-                                           _("I_gnore All"));
+    widget = gtk_button_new_with_mnemonic(_("I_gnore All"));
     gtk_widget_set_tooltip_text(widget,
                                 _("Skip all occurrences of the current word"));
     g_signal_connect(widget, "clicked",
 		     G_CALLBACK(ignore_all_cb), spell_check);
     gtk_grid_attach(grid, widget, 1, 1, 1, 1);
 
-    widget = balsa_stock_button_with_label(BALSA_PIXMAP_BOOK_OPEN,
-                                           _("_Learn"));
+    widget = gtk_button_new_with_mnemonic(_("_Learn"));
     gtk_widget_set_tooltip_text(widget,
                                 _("Add the current word to your personal dictionary"));
     g_signal_connect(widget, "clicked",
 		     G_CALLBACK(learn_cb), spell_check);
     gtk_grid_attach(grid, widget, 2, 0, 1, 1);
 
-    widget = balsa_stock_button_with_label(GTK_STOCK_OK, _("_Done"));
+    widget = gtk_button_new_with_mnemonic(_("_Done"));
     gtk_widget_set_tooltip_text(widget, _("Finish spell checking"));
     g_signal_connect(widget, "clicked",
 		     G_CALLBACK(done_cb), spell_check);
     gtk_grid_attach(grid, widget, 3, 0, 1, 1);
 
-    widget = balsa_stock_button_with_label(GTK_STOCK_CANCEL, _("_Cancel"));
+    widget = gtk_button_new_with_mnemonic(_("_Cancel"));
     gtk_widget_set_tooltip_text(widget,
                                 _("Revert all changes and finish spell checking"));
     g_signal_connect(widget, "clicked",
 		     G_CALLBACK(cancel_cb), spell_check);
     gtk_grid_attach(grid, widget, 3, 1, 1, 1);
-
-    gtk_window_set_title(GTK_WINDOW(spell_check), _("Spell check"));
 }
 
 
@@ -575,8 +582,7 @@ balsa_spell_check_start(BalsaSpellCheck * spell_check)
                                    "%s",
                                    enchant_error);
 
-	/* Generate a response signal. */
-	gtk_dialog_response(GTK_DIALOG(spell_check), 0);
+	gtk_widget_destroy((GtkWidget *) spell_check);
 
 	return;
     }
@@ -599,12 +605,23 @@ balsa_spell_check_start(BalsaSpellCheck * spell_check)
         gtk_text_buffer_create_mark(buffer, NULL, &start, FALSE);
 
     /* Get the original text so we can always revert */
+#if HAVE_GTKSOURCEVIEW
+    spell_check->original_text =
+	gtk_source_buffer_new(gtk_text_buffer_get_tag_table(buffer));
+    gtk_text_buffer_get_start_iter((GtkTextBuffer *)
+                                   spell_check->original_text, &iter);
+    gtk_text_buffer_get_bounds((GtkTextBuffer *) buffer, &start, &end);
+    gtk_text_buffer_insert_range((GtkTextBuffer *)
+                                 spell_check->original_text, &iter,
+                                 &start, &end);
+#else                           /* HAVE_GTKSOURCEVIEW */
     spell_check->original_text =
 	gtk_text_buffer_new(gtk_text_buffer_get_tag_table(buffer));
     gtk_text_buffer_get_start_iter(spell_check->original_text, &iter);
     gtk_text_buffer_get_bounds(buffer, &start, &end);
     gtk_text_buffer_insert_range(spell_check->original_text, &iter,
                                  &start, &end);
+#endif                          /* HAVE_GTKSOURCEVIEW */
 
     if (balsa_app.debug)
 	balsa_information(LIBBALSA_INFORMATION_DEBUG,
@@ -839,7 +856,7 @@ balsa_spell_check_destroy(GObject * object)
     }
 
     if (spell_check->broker) {
-	spch_finish(spell_check, TRUE);
+	spch_finish(spell_check, FALSE);
     }
 
     g_free(spell_check->language_tag);
@@ -866,9 +883,8 @@ balsa_spell_check_destroy(GObject * object)
 
 
 /* spch_finish ()
- * 
- * Clean up the variables from the spell check, and emit the done
- * signal so that the main program knows to resume normal operation.
+ *
+ * Clean up the variables from the spell check
  * */
 static void
 spch_finish(BalsaSpellCheck * spell_check, gboolean keep_changes)
@@ -888,7 +904,11 @@ spch_finish(BalsaSpellCheck * spell_check, gboolean keep_changes)
         g_object_unref(spell_check->original_text);
     } else {
 	/* replace corrected text with original text */
+#if HAVE_GTKSOURCEVIEW
+        buffer = (GtkTextBuffer *) spell_check->original_text;
+#else                           /* HAVE_GTKSOURCEVIEW */
         buffer = spell_check->original_text;
+#endif                          /* HAVE_GTKSOURCEVIEW */
         gtk_text_view_set_buffer(spell_check->text_view, buffer);
         gtk_text_buffer_get_iter_at_offset(buffer, &original,
                                            spell_check->original_offset);
@@ -913,8 +933,7 @@ spch_finish(BalsaSpellCheck * spell_check, gboolean keep_changes)
 	balsa_information(LIBBALSA_INFORMATION_DEBUG,
 			  "BalsaSpellCheck: Finished\n");
 
-    /* Generate a response signal. */
-    gtk_dialog_response(GTK_DIALOG(spell_check), 0);
+    gtk_widget_destroy((GtkWidget *) spell_check);
 }
 
 
