@@ -42,6 +42,9 @@
 #define MAX(a, b) ((a) > (b) ? (a) : (b))
 #endif
 
+/* Uncomment the next line to check for invalid action names */
+/* #define BALSA_TOOLBAR_DEBUG_ACTIONS */
+
 /* Enumeration for GtkTreeModel columns. */
 enum {
     TP_TEXT_COLUMN,
@@ -89,11 +92,15 @@ static void current_row_activated_cb(GtkTreeView * treeview,
 
 /* Helpers. */
 static GtkWidget *create_toolbar_page(BalsaToolbarModel * model,
-                                      GtkUIManager * ui_manager);
+                                      GActionMap        * map);
 static GtkWidget *tp_list_new(void);
 static gboolean tp_list_iter_is_first(GtkWidget * list, GtkTreeIter * iter);
 static gboolean tp_list_iter_is_last(GtkWidget * list, GtkTreeIter * iter);
+#ifndef BALSA_TOOLBAR_DEBUG_ACTIONS
 static void tp_page_refresh_available(ToolbarPage * page);
+#else /* BALSA_TOOLBAR_DEBUG_ACTIONS */
+static void tp_page_refresh_available(ToolbarPage * page, GActionMap * map);
+#endif /* BALSA_TOOLBAR_DEBUG_ACTIONS */
 static void tp_page_refresh_current(ToolbarPage * page);
 static void tp_page_refresh_preview(ToolbarPage * page);
 static void tp_page_swap_rows(ToolbarPage * page, gboolean forward);
@@ -116,9 +123,9 @@ customize_dialog_cb(GtkWidget * widget, gpointer data)
     GtkWidget *option_box;
     GtkWidget *wrap_button;
     GtkWidget *active_window = data;
-    BalsaToolbarModel *model;
     BalsaToolbarType   type;
-    GtkUIManager * ui_manager;
+    BalsaToolbarModel *model;
+    GSimpleActionGroup *group;
     GtkWidget *content_area;
 
     /* There can only be one */
@@ -130,9 +137,10 @@ customize_dialog_cb(GtkWidget * widget, gpointer data)
     customize_widget =
         gtk_dialog_new_with_buttons(_("Customize Toolbars"),
                                     GTK_WINDOW(active_window),
-                                    GTK_DIALOG_DESTROY_WITH_PARENT,
-                                    GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-                                    GTK_STOCK_HELP,  GTK_RESPONSE_HELP,
+                                    GTK_DIALOG_DESTROY_WITH_PARENT |
+                                    GTK_DIALOG_USE_HEADER_BAR,
+                                    _("_Close"), GTK_RESPONSE_CLOSE,
+                                    _("_Help"),  GTK_RESPONSE_HELP,
                                     NULL);
 #if HAVE_MACOSX_DESKTOP
     libbalsa_macosx_menu_for_parent(customize_widget, GTK_WINDOW(active_window));
@@ -145,7 +153,7 @@ customize_dialog_cb(GtkWidget * widget, gpointer data)
     notebook = gtk_notebook_new();
     content_area =
         gtk_dialog_get_content_area(GTK_DIALOG(customize_widget));
-    gtk_container_add(GTK_CONTAINER(content_area), notebook);
+    gtk_box_pack_start(GTK_BOX(content_area), notebook, TRUE, TRUE, 0);
 
     gtk_window_set_wmclass(GTK_WINDOW(customize_widget), "customize",
                            "Balsa");
@@ -154,23 +162,35 @@ customize_dialog_cb(GtkWidget * widget, gpointer data)
     /* The order of pages must be consistent with the BalsaToolbarType
      * enum. */
     model = balsa_window_get_toolbar_model();
-    ui_manager = balsa_window_ui_manager_new(NULL);
-    child = create_toolbar_page(model, ui_manager);
-    g_object_unref(ui_manager);
+    group = g_simple_action_group_new();
+    balsa_window_add_action_entries(G_ACTION_MAP(group));
+#ifdef BALSA_TOOLBAR_DEBUG_ACTIONS
+    g_print("main window\n");
+#endif /* BALSA_TOOLBAR_DEBUG_ACTIONS */
+    child = create_toolbar_page(model, G_ACTION_MAP(group));
+    g_object_unref(group);
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook), child,
                              gtk_label_new(_("Main window")));
 
     model = sendmsg_window_get_toolbar_model();
-    ui_manager = sendmsg_window_ui_manager_new(NULL);
-    child = create_toolbar_page(model, ui_manager);
-    g_object_unref(ui_manager);
+    group = g_simple_action_group_new();
+    sendmsg_window_add_action_entries(G_ACTION_MAP(group));
+#ifdef BALSA_TOOLBAR_DEBUG_ACTIONS
+    g_print("compose window\n");
+#endif /* BALSA_TOOLBAR_DEBUG_ACTIONS */
+    child = create_toolbar_page(model, G_ACTION_MAP(group));
+    g_object_unref(group);
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook), child,
                              gtk_label_new(_("Compose window")));
 
     model = message_window_get_toolbar_model();
-    ui_manager = message_window_ui_manager_new(NULL);
-    child = create_toolbar_page(model, ui_manager);
-    g_object_unref(ui_manager);
+    group = g_simple_action_group_new();
+    message_window_add_action_entries(G_ACTION_MAP(group));
+#ifdef BALSA_TOOLBAR_DEBUG_ACTIONS
+    g_print("message window\n");
+#endif /* BALSA_TOOLBAR_DEBUG_ACTIONS */
+    child = create_toolbar_page(model, G_ACTION_MAP(group));
+    g_object_unref(group);
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook), child,
                              gtk_label_new(_("Message window")));
 
@@ -235,7 +255,8 @@ wrap_toggled_cb(GtkWidget * widget, GtkNotebook * notebook)
 
     for (i = 0; (child = gtk_notebook_get_nth_page(notebook, i)); i++) {
         page = g_object_get_data(G_OBJECT(child), BALSA_KEY_TOOLBAR_PAGE);
-        balsa_toolbar_model_changed(page->model);
+        if (page)
+            balsa_toolbar_model_changed(page->model);
     }
 }
 
@@ -273,7 +294,11 @@ standard_button_cb(GtkWidget *widget, ToolbarPage * page)
 {
     balsa_toolbar_model_clear(page->model);
     gtk_widget_set_sensitive(page->standard_button, FALSE);
+#ifndef BALSA_TOOLBAR_DEBUG_ACTIONS
     tp_page_refresh_available(page);
+#else /* BALSA_TOOLBAR_DEBUG_ACTIONS */
+    tp_page_refresh_available(page, NULL);
+#endif /* BALSA_TOOLBAR_DEBUG_ACTIONS */
     tp_page_refresh_current(page);
     balsa_toolbar_model_changed(page->model);
 }
@@ -350,7 +375,7 @@ tp_dialog_response_cb(GtkDialog * dialog, gint response, gpointer data)
         break;
     case GTK_RESPONSE_HELP:
         screen = gtk_widget_get_screen(GTK_WIDGET(dialog));
-        gtk_show_uri(screen, "ghelp:balsa?toolbar-prefs",
+        gtk_show_uri(screen, "help:balsa/toolbar-prefs",
                      gtk_get_current_event_time(), &err);
         if (err) {
             balsa_information(LIBBALSA_INFORMATION_WARNING,
@@ -369,7 +394,7 @@ tp_dialog_response_cb(GtkDialog * dialog, gint response, gpointer data)
 /* Create a page for the main notebook.
  */
 static GtkWidget*
-create_toolbar_page(BalsaToolbarModel * model, GtkUIManager * ui_manager)
+create_toolbar_page(BalsaToolbarModel * model, GActionMap * map)
 {
     GtkWidget *outer_box;
     GtkWidget *toolbar_frame, *toolbar_scroll;
@@ -398,15 +423,8 @@ create_toolbar_page(BalsaToolbarModel * model, GtkUIManager * ui_manager)
     gtk_container_add(GTK_CONTAINER(toolbar_frame), toolbar_ctlbox);
     gtk_container_set_border_width(GTK_CONTAINER(toolbar_ctlbox), 5);
 
-    /* The ui-manager has actions but no ui, so we add an empty toolbar. */
-    gtk_ui_manager_add_ui_from_string(ui_manager,
-                                      "<ui>"
-                                      "  <toolbar name='Toolbar'/>"
-                                      "</ui>",
-                                      -1, NULL);
-
     /* The preview is an actual, fully functional toolbar */
-    page->toolbar = balsa_toolbar_new(model, ui_manager);
+    page->toolbar = balsa_toolbar_new(model, map);
     gtk_widget_set_sensitive(page->toolbar, FALSE);
 
     /* embedded in a scrolled_window */
@@ -427,6 +445,7 @@ create_toolbar_page(BalsaToolbarModel * model, GtkUIManager * ui_manager)
 
     /* Button box */
     button_box = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
+    gtk_box_set_spacing(GTK_BOX(button_box), 5);
     gtk_box_pack_start(GTK_BOX(toolbar_ctlbox), button_box, FALSE, FALSE, 0);
 
     /* Standard button */
@@ -486,23 +505,35 @@ create_toolbar_page(BalsaToolbarModel * model, GtkUIManager * ui_manager)
 		       FALSE, FALSE, 0);
 
     page->back_button =
-        balsa_stock_button_with_label(GTK_STOCK_GO_UP, _("Up"));
+        gtk_button_new_from_icon_name("go-up-symbolic",
+                                      GTK_ICON_SIZE_BUTTON);
+    gtk_widget_set_tooltip_text(page->back_button,
+                                _("Move selected item up"));
     gtk_box_pack_start(GTK_BOX(button_box), page->back_button, FALSE, FALSE, 0);
 
     move_button_box=gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_box_pack_start(GTK_BOX(button_box), move_button_box, FALSE, FALSE, 0);
 
     page->remove_button =
-        balsa_stock_button_with_label(GTK_STOCK_GO_BACK, "-");
+        gtk_button_new_from_icon_name("go-previous-symbolic",
+                                      GTK_ICON_SIZE_BUTTON);
+    gtk_widget_set_tooltip_text(page->remove_button,
+                                _("Remove selected item from toolbar"));
     gtk_box_pack_start(GTK_BOX(move_button_box), page->remove_button,
                        FALSE, FALSE, 0);
 
     page->add_button =
-        balsa_stock_button_with_label(GTK_STOCK_GO_FORWARD, "+");
+        gtk_button_new_from_icon_name("go-next-symbolic",
+                                      GTK_ICON_SIZE_BUTTON);
+    gtk_widget_set_tooltip_text(page->add_button,
+                                _("Add selected item to toolbar"));
     gtk_box_pack_start(GTK_BOX(move_button_box), page->add_button, FALSE, FALSE, 0);
 
     page->forward_button =
-        balsa_stock_button_with_label(GTK_STOCK_GO_DOWN, _("Down"));
+        gtk_button_new_from_icon_name("go-down-symbolic",
+                                      GTK_ICON_SIZE_BUTTON);
+    gtk_widget_set_tooltip_text(page->forward_button,
+                                _("Move selected item down"));
     gtk_box_pack_start(GTK_BOX(button_box), page->forward_button, FALSE, FALSE, 0);
 
     /* Pack destination list */
@@ -544,7 +575,11 @@ create_toolbar_page(BalsaToolbarModel * model, GtkUIManager * ui_manager)
     gtk_widget_set_sensitive(page->standard_button,
                              !balsa_toolbar_model_is_standard(model));
 
+#ifndef BALSA_TOOLBAR_DEBUG_ACTIONS
     tp_page_refresh_available(page);
+#else /* BALSA_TOOLBAR_DEBUG_ACTIONS */
+    tp_page_refresh_available(page, map);
+#endif /* BALSA_TOOLBAR_DEBUG_ACTIONS */
     tp_page_refresh_current(page);
 
     return outer_box;
@@ -552,8 +587,24 @@ create_toolbar_page(BalsaToolbarModel * model, GtkUIManager * ui_manager)
 
 /* Refresh the page's available GtkTreeView.
  */
+static gboolean
+tp_find_icon(GArray * array, const gchar * icon)
+{
+    guint j;
+
+    for (j = 0; j < array->len; j++) {
+        if (strcmp(icon, g_array_index(array, BalsaToolbarEntry, j).icon) == 0)
+            return TRUE;
+    }
+    return FALSE;
+}
+
 static void
+#ifndef BALSA_TOOLBAR_DEBUG_ACTIONS
 tp_page_refresh_available(ToolbarPage * page)
+#else /* BALSA_TOOLBAR_DEBUG_ACTIONS */
+tp_page_refresh_available(ToolbarPage * page, GActionMap * map)
+#endif /* BALSA_TOOLBAR_DEBUG_ACTIONS */
 {
     GtkTreeSelection *selection =
         gtk_tree_view_get_selection(GTK_TREE_VIEW(page->available));
@@ -561,7 +612,7 @@ tp_page_refresh_available(ToolbarPage * page)
     GtkTreeIter iter;
     GtkTreePath *path;
     GHashTable *legal = balsa_toolbar_model_get_legal(page->model);
-    GSList *current = balsa_toolbar_model_get_current(page->model);
+    GArray *current = balsa_toolbar_model_get_current(page->model);
     int item;
 
     /* save currently selected path, or point path to the first row */
@@ -574,12 +625,21 @@ tp_page_refresh_available(ToolbarPage * page)
     gtk_list_store_clear(GTK_LIST_STORE(model));
 
     for (item = 0; item < toolbar_button_count; item++) {
+#ifdef BALSA_TOOLBAR_DEBUG_ACTIONS
+        if (map) {
+            if (item > 0) {
+                gchar *action;
+
+                action = g_hash_table_lookup(legal, toolbar_buttons[item].pixmap_id);
+                if (action && !g_action_map_lookup_action(map, action))
+                    g_print("undefined action: \"%s\"\n", action);
+            }
+        }
+#endif /* BALSA_TOOLBAR_DEBUG_ACTIONS */
         if (item > 0
             && (!g_hash_table_lookup(legal,
                                      toolbar_buttons[item].pixmap_id)
-                || g_slist_find_custom(current,
-                                       toolbar_buttons[item].pixmap_id,
-                                       (GCompareFunc) strcmp)))
+                || tp_find_icon(current, toolbar_buttons[item].pixmap_id)))
             continue;
 
         gtk_list_store_append(GTK_LIST_STORE(model), &iter);
@@ -606,7 +666,8 @@ tp_page_refresh_current(ToolbarPage * page)
     GtkTreeIter iter;
     GtkTreePath *path;
     int item;
-    GSList *list;
+    GArray *current;
+    guint j;
 
     /* save currently selected path, or point path to the first row */
     if (gtk_tree_selection_get_selected(selection, &model, &iter))
@@ -617,9 +678,13 @@ tp_page_refresh_current(ToolbarPage * page)
     }
     gtk_list_store_clear(GTK_LIST_STORE(model));
 
-    for (list = balsa_toolbar_model_get_current(page->model); list;
-         list = g_slist_next(list)) {
-        item = get_toolbar_button_index(list->data);
+    current = balsa_toolbar_model_get_current(page->model);
+    for (j = 0; j < current->len; j++) {
+        BalsaToolbarEntry *entry;
+
+        entry = &g_array_index(current, BalsaToolbarEntry, j);
+        item = get_toolbar_button_index(entry->icon);
+
         if (item < 0)
             continue;
 
@@ -777,10 +842,10 @@ tp_store_set(GtkListStore * store, GtkTreeIter * iter, gint item)
     text = g_strdup(balsa_toolbar_button_text(item));
     replace_nl_with_space(text);
     pixbuf =
-        (item > 0 ? gtk_widget_render_icon_pixbuf(customize_widget,
-                                                  toolbar_buttons[item].
-                                                  pixmap_id,
-                                                  GTK_ICON_SIZE_LARGE_TOOLBAR)
+        (item > 0
+         ? gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
+                                    toolbar_buttons[item].pixmap_id,
+                                    GTK_ICON_SIZE_LARGE_TOOLBAR, 0, NULL)
          : NULL);
     gtk_list_store_set(store, iter,
                        TP_TEXT_COLUMN, text,
@@ -827,7 +892,11 @@ tp_page_add_selected(ToolbarPage * page)
 
     gtk_widget_set_sensitive(page->standard_button, TRUE);
     tp_page_refresh_preview(page);
+#ifndef BALSA_TOOLBAR_DEBUG_ACTIONS
     tp_page_refresh_available(page);
+#else /* BALSA_TOOLBAR_DEBUG_ACTIONS */
+    tp_page_refresh_available(page, NULL);
+#endif /* BALSA_TOOLBAR_DEBUG_ACTIONS */
     balsa_toolbar_model_changed(page->model);
 }
 
@@ -858,7 +927,11 @@ tp_page_remove_selected(ToolbarPage * page)
 
     gtk_widget_set_sensitive(page->standard_button, TRUE);
     tp_page_refresh_preview(page);
+#ifndef BALSA_TOOLBAR_DEBUG_ACTIONS
     tp_page_refresh_available(page);
+#else /* BALSA_TOOLBAR_DEBUG_ACTIONS */
+    tp_page_refresh_available(page, NULL);
+#endif /* BALSA_TOOLBAR_DEBUG_ACTIONS */
     balsa_toolbar_model_changed(page->model);
 }
 
